#!/usr/bin/perl

###########################################################################
#            Copyright (C) 2000 John David Ratliff                        #
#                                                                         #
# Permission is hereby granted, free of charge, to any person obtaining   #
# a copy of this software and associated documentation files (the         #
# "Software"), to deal in the Software without restriction, including     #
# without limitation the rights to use, copy, modify, merge, publish,     #
# distribute, sublicense, and/or sell copies of the Software, and to      #
# permit persons to whom the Software is furnished to do so, subject to   #
# the following conditions:                                               #
#                                                                         #
# The above copyright notice and this permission notice shall be included #
# in all copies or substantial portions of the Software.                  #
#                                                                         #
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,         #
# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF      #
# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  #
# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY    #
# CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,    #
# TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE       #
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.                  #
###########################################################################

use CGI qw(:param);
use DBI;

require "lib/dbi-connect.pl";
require "lib/error.pl";

#########################################################################################################
#
# Declare the local variables, print the content type, set the script variable, establish the database
# connection and print the header
#

local ($script,$dbh,$error,$name,$email,$question,$feedback);

print "Content-type: text/html\n\n";

$script = "feedback.cgi";
$dbh = dbiConnect($dbname);

print <<HTML;
<html>

<head>
	<title>Feedback Form</title>

	<style fprolloverstyle>
		A:hover {color: darkgreen; font-weight: bold}
	</style>
</head>

<body background="/images/background.gif" link="#800000" vlink="#C00000" alink="#000080">
HTML

#########################################################################################################
#
# Send an email response to a question based on the question number sent by the feedback form. If the
# question is not one of the standard questions, then record it in the database and notify the staff.
#

if (param()) {
	$name = param("name");
	$email = param("email");
	$question = param("question");
	$feedback = param("feedback");

	if ($name eq "" or $email eq "" or (($email =~ /^\w{1,}@.+\.[A-z]{2,4}$/) == 0) or ($feedback eq "" && $question == 1000)) {
		print qq|<h3 align="center">You forgot to fill in either the name, email or feedback fields.</h3>\n|;
		print qq|<h4 align="center">Please press the BACK button to correct this.</h4>\n|;
	} else {
		if ($question == 1) {
			open(MAIL,"|/usr/sbin/sendmail ${email}");
			print MAIL "To: ${name} <${email}>\n";
			print MAIL "From: Library Staff <${staffmail}>\n";
			print MAIL "Subject: Re: What Are Your Checkout Policies?\n\n";
			print MAIL "You may checkout 5 books and 2 movies at any one time. Movies are due back in 3 days, but books may be kept for two weeks.\n\n";
			print MAIL "Note: This is an automatically generated response. If you have further questions, please reply to this email.\n";
			print MAIL "\nLibrary Staff\n${staffmail}\n\n";
			close(MAIL);
		} elsif ($question == 2) {
			open(MAIL,"|/usr/sbin/sendmail ${email}");
			print MAIL "To: ${name} <${email}>\n";
			print MAIL "From: Library Staff <${staffmail}>\n";
			print MAIL "Subject: Re: How do your late fees accrue?\n\n";
			print MAIL "When a book is more than 1 week overdue, 10 cents is assessed for every day after that for which it is not returned. After 3 months, a replacement cost will be assessed IN ADDITION to the late fees.\n";
			print MAIL "When a movie is three days overdue, 50 cents is assessed for each day it remains unreturned. After 3 months, a replacement cost will be assessed IN ADDITION to the late fees.\n\n";
			print MAIL "Note: This is an automatically generated response. If you have further questions, please reply to this email.\n";
			print MAIL "\nLibrary Staff\n${staffmail}\n\n";
			close(MAIL);
		} elsif ($question == 3) {
			open(MAIL,"|/usr/sbin/sendmail ${email}");
			print MAIL "To: ${name} <${email}>\n";
			print MAIL "From: Library Staff <${staffmail}>\n";
			print MAIL "Subject: Re: What is your RESERVATION policy?\n\n";
			print MAIL "To reserve books, first use the search form to find the correct book. Then press the button marked 'Reserve This Book/Movie' and the item will be reserved for you.\n";
			print MAIL "When your item is availble, you will be sent an email notice and given 7 days to pick the item up. If you do not pick the item up within the 7 days, your reservation will expire and the book will go back to the shelves.\n\n";
			print MAIL "Note: This is an automatically generated response. If you have further questions, please reply to this email.\n";
			print MAIL "\nLibrary Staff\n${staffmail}\n\n";
			close(MAIL);
		} else {
			$sql = "insert into feedback (name,email,feedback) values (?,?,?)";
			$sth = $dbh->prepare($sql);
			$sth->execute($name,$email,$feedback);
			$error = $dbh->errstr;
			$id = $sth->{'mysql_insertid'};
			$sth->finish;

			if ($error ne "") {
				handle($error,$script);
				die "Database Error: ${error}";
			}

			open(MAIL,"|/usr/sbin/sendmail ${staffmail}");
			print MAIL "To: Library Staff <${staffmail}>\n";
			print MAIL "From: Feedback Form Script <${staffmail}>\n";
			print MAIL "Subject: New Feedback\n\n";
			print MAIL "Read This Feedback at ${server}/staff/feedback.cgi?id=${id}&action=1\n";
			print MAIL "Look at all the feedback at ${server}/staff/feedback.cgi\n";
			print MAIL "\n\nDELETE USER FEEDBACK BY CLICKING HERE: ${server}/staff/feedback.cgi?id=${id}&action=2\n";
			print MAIL "\nFeedback Form\n${staffmail}\n\n";
			close(MAIL);
		}

		if ($error ne "") {
			handle($error,$script);
			die "Database Error: ${error}";
		}

		print qq|<h3 align="center">Your feedback has been received and will be answered as soon as possible.</h3>\n|;
	}

#########################################################################################################
#
# Print the feedback form if we haven't already done so.
#
#

} else {
	print <<HTML;
<h1 align="center">Feedback Form</h1>

<center>
	<form method="POST" action="feedback.cgi">
		<table width="75%" border="1" bgcolor="#000000">
			<tr>
				<td width="20%" bgcolor="#D3C1B6">Name: </td>
				<td width="80%" bgcolor="#D3C1B6"><input type="text" name="name" size="30"></td>
			</tr>

			<tr>
				<td width="20%" bgcolor="#D3C1B6">E-Mail: </td>
				<td width="80%" bgcolor="#D3C1B6"><input type="text" name="email" size="30"></td>
			</tr>

			<tr>
				<td width="20%" bgcolor="#D3C1B6">Question Type: </td>
				<td width="80%" bgcolor="#D3C1B6">
					<select name="question" height="1">
						<option selected value="1">What are your Checkout Policies?</option>
						<option value="2">How do your late fees accure?</option>
						<option value="3">What is your RESERVATION Policy?</option>
						<option value="1000">Other, Please Explain</option>
					</select>
				</td>
			</tr>

			<tr>
				<td width="20%" bgcolor="#D3C1B6">Feedback: </td>
				<td width="80%" bgcolor="#D3C1B6"><textarea name="feedback" cols="40" rows="7"></textarea></td>
			</tr>

			<tr>
				<td width="100%" colspan="2" align="left" bgcolor="#D3C1B6"><input type="submit" value="Send Feedback"></td>
			</tr>
		</table>
	</form>
</center>
HTML
}

print qq|<center><a href="index.html"><strong>Return to the Main Page</strong></a><br><img border="0" src="/images/book.gif" width="116" height="68"></center>\n</body>\n</html>\n|;

$dbh->disconnect;
