#!/usr/bin/perl

###########################################################################
#            Copyright (C) 2000 John David Ratliff                        #
#                                                                         #
# Permission is hereby granted, free of charge, to any person obtaining   #
# a copy of this software and associated documentation files (the         #
# "Software"), to deal in the Software without restriction, including     #
# without limitation the rights to use, copy, modify, merge, publish,     #
# distribute, sublicense, and/or sell copies of the Software, and to      #
# permit persons to whom the Software is furnished to do so, subject to   #
# the following conditions:                                               #
#                                                                         #
# The above copyright notice and this permission notice shall be included #
# in all copies or substantial portions of the Software.                  #
#                                                                         #
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,         #
# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF      #
# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  #
# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY    #
# CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,    #
# TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE       #
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.                  #
###########################################################################

use CGI qw(:param);
use DBI;

require "lib/dbi-connect.pl";
require "lib/error.pl";

#########################################################################################################
#
# Declare the local variables, print the content type, set the script variable, establish the database
# connection and print the header
#

local ($script,$dbh,$error,$id,$username,$password,$sql,$sth,$pass2);
local ($reserve,$patron,$media,$sg,$author,$name,$title,$uid,$email);

print "Content-type: text/html\n\n";

$script = "reserve.cgi";
$dbh = dbiConnect($dbname);

print <<HTML;
<html>

<head>
	<title>Reserve an Item</title>

	<style fprolloverstyle>
		A:hover {color: darkgreen; font-weight: bold}
	</style>
</head>

<body background="/images/background.gif" link="#800000" vlink="#C00000" alink="#000080">
HTML

$id = param("id");
$id = int($id);

#########################################################################################################
#
# Cancel a reservation for a patron based on the catalog ID and the patron's username.
#
#

if (param("cancel")) {
	$username = param("username");
	$password = param("password");

	$sql = "select name,password from patrons where username = ?";
	$sth = $dbh->prepare($sql);
	$sth->execute($username);
	$error = $dbh->errstr;
	($name,$pass2) = $sth->fetchrow_array();
	$sth->finish;

	if ($error ne "") {
		handle($error,$script);
		die "Database Error: ${error}";
	}

	if ($password eq $pass2) {
		$sql = "update catalog set reserve = 0 where id = $id";
		$dbh->do($sql);
		$error = $dbh->errstr;

		if ($error ne "") {
			handle($error,$script);
			die "Database Error: ${error}";
		}

		$sql = "select title from catalog where id = ?";
		$sth = $dbh->prepare($sql);
		$sth->execute($id);
		$error = $dbh->errstr;
		$title = $sth->fetchrow_array();
		$sth->finish;

		if ($error ne "") {
			handle($error,$script);
			die "Database Error: ${error}";
		}

		open(MAIL,"|/usr/sbin/sendmail ${staffmail}");
		print MAIL "To: Library Staff <${staffmail}>\n";
		print MAIL "From: Reservation System <${staffmail}>\n";
		print MAIL "Subject: Reservation Cancelled.\n\n";
		print MAIL "User ${name} has cancelled their request for ${title}.\n";
		print MAIL "\nReservation System\n${staffmail}\n\n";
		close(MAIL);

		print qq|<h3 align="center">Your reservation has been cancelled.</h3>\n|;
	} else {
		print qq|<h3 align="center">Invalid username or password.</h3>\n|;
	}

#########################################################################################################
#
# Confirm the login information (username/password) and reserve the item if it checks out.
#
#

} elsif (param("login")) {
	$username = param("username");
	$password = param("password");


	if ($password eq "" or $username eq "") {
		print qq|<h3 align="center">You cannot leave the username or password fields blank!</h3>\n|;
		print qq|<h4 align="center">Press the back button to correct this.</h4>\n|;
	} else {
		$sql = "select password(?)";
		$sth = $dbh->prepare($sql);
		$sth->execute($password);
		$error = $dbh->errstr;
		$password = $sth->fetchrow_array();
		$sth->finish;

		if ($error ne "") {
			handle($error,$script);
			die "Database Error: ${error}";
		}

		$sql = "select id,name,email,password from patrons where username = ?";
		$sth = $dbh->prepare($sql);
		$sth->execute($username);
		$error = $dbh->errstr;
		($uid,$name,$email,$pass2) = $sth->fetchrow_array();
		$sth->finish;

		if ($error ne "") {
			handle($error,$script);
			die "Database Error: ${error}";
		}

		if ($password eq $pass2) {
			$sql = "select reserve from catalog where id = ?";
			$sth = $dbh->prepare($sql);
			$sth->execute($id);
			$error = $dbh->errstr;
			$reserve = $sth->fetchrow_array();
			$sth->finish;

			if ($error ne "") {
				handle($error,$script);
				die "Database Error: ${error}";
			}

			if ($reserve == $uid) {
				print qq|<h3 align="center">That item has already been reserved by you. Do you wish to cancel that reservation?</h3>|;
				print qq|<center><form method="POST" action="reserve.cgi"><input type="hidden" name="cancel" value="1"><input type="hidden" name="username" value="${username}"><input type="hidden" name="password" value="${password}"><input type="hidden" name="id" value="${id}"><input type="submit" value="Yes, Cancel Reservation"></form></center>\n|;
			} elsif ($reserve != 0) {
				print qq|<h3 align="center">I am sorry, but that item is already on reserve. Please try again later.</h3>\n|;
			} else {
				$sql = "select patron from catalog where id = ?";
				$sth = $dbh->prepare($sql);
				$sth->execute($id);
				$error = $dbh->errstr;
				$patron = $sth->fetchrow_array();
				$sth->finish;

				if ($error ne "") {
					handle($error,$script);
					die "Database Error: ${error}";
				}

				$sql = "select media,title,author,sg from catalog where id = ?";
				$sth = $dbh->prepare($sql);
				$sth->execute($id);
				$error = $dbh->errstr;
				($media,$title,$author,$sg) = $sth->fetchrow_array();
				$sth->finish;

				if ($error ne "") {
					handle($error,$script);
					die "Database Error: ${error}";
				}

				if ($patron == 0) {
					$sql = "update catalog set reserve = $uid, rtime = NULL where id = $id";
					$dbh->do($sql);
					$error = $dbh->errstr;

					if ($error ne "") {
						handle($error,$script);
						die "Database Error: ${error}";
					}

					open(MAIL,"|/usr/sbin/sendmail ${staffmail}");
					print MAIL "To: Library Staff <${staffmail}>\n";
					print MAIL "From: Reservation Script <${staffmail}>\n";
					print MAIL "Subject: Reservation Request.\n\n";
					print MAIL "Patron ID: ${uid}\n";
					print MAIL "Patron Name: ${name}\n\n";
					print MAIL "Catalog ID: ${id}\n";
					print MAIL "Title: ${title}\n";

					if ($media == 1) {
						print MAIL "Author: ${author}\n";
						print MAIL "Subject: ${subject}\n";
					} elsif ($media == 2) {
						print MAIL "Genre: ${genre}\n";
					}

					print MAIL "\nTo reserve this item for this patron, point your browser to this URL: ${server}/staff/reserve.cgi?id=${id}&patron=${uid}&media=${media}";
					print MAIL "\nLibrary Staff\n${staffmail}\n\n";
					close(MAIL);

					print qq|<h3 align="center">Your request has been sent to the library. You will be notified when your item is ready.</h3>\n|;
				} else {
					if ($patron == $uid) {
						print qq|<h3 align="center">This item is already checked out in your name!</h3>\n|;
					} else {
						$sql = "update catalog set reserve = $uid, rtime = NULL where id = $id";
						$dbh->do($sql);
						$error = $dbh->errstr;

						if ($error ne "") {
							handle($error,$script);
							die "Database Error: ${error}";
						}

						print qq|<h3 align="center">This item is currently checked out, but when it is returned, it will be reserved for you.</h3>\n|;
					}
				}
			}
		} else {
			print qq|<h3 align="center">Invalid Username or Password.</h3>\n|;
			print qq|<h4 align="center">Press the BACK Button to Correct This.</h4>\n|;
		}
	}

#########################################################################################################
#
# Print the login form for the user to access his or her account.
#
#

} elsif (param()) {
	print qq|<h1 align="center">Login to Your Account</h1>\n|;
	print qq|<center><table width="75%" border="1" bgcolor="#000000"><form method="POST" action="reserve.cgi">\n|;
	print qq|<input type="hidden" name="id" value="${id}"><input type="hidden" name="login" value="1">\n|;
	print qq|<tr><td width="100%" align="center" colspan="2" bgcolor="#D3C1B6"><strong>Please Login to Your Account</strong></td></tr>\n|;
	print qq|<tr><td width="20%" bgcolor="#D3C1B6">Username: </td><td width="80%" bgcolor="#D3C1B6"><input type="text" name="username" size="20"> <font size="-1"><a href="newpatron.html">Need an Account</a> or <a href="lookup.html">Forget Your Username?</a></font></td></tr>\n|;
	print qq|<tr><td width="20%" bgcolor="#D3C1B6">Password: </td><td width="80%" bgcolor="#D3C1B6"><input type="password" name="password" size="20"> <font size="-1"><a href="lookup.html">Forget Your Password?</a></font></td></tr>\n|;
	print qq|<tr><td width="100%" align="left" colspan="2" bgcolor="#D3C1B6"><input type="submit" value="Login"></td></tr>\n|;
	print qq|</table></form></center>\n|;

#########################################################################################################
#
# Don't allow people to access the form without using either the search or reservation form.
#
#

} else {
	print qq|<h1 align="center">Please use the reservation or the search form.</h1>\n|;
}

print qq|<center><a href="index.html"><strong>Return to the Main Page</strong></a><br><img border="0" src="/images/book.gif" width="116" height="68"></center>\n</body>\n</html>\n|;

$dbh->disconnect;
