#!/usr/bin/perl

###########################################################################
#            Copyright (C) 2000 John David Ratliff                        #
#                                                                         #
# Permission is hereby granted, free of charge, to any person obtaining   #
# a copy of this software and associated documentation files (the         #
# "Software"), to deal in the Software without restriction, including     #
# without limitation the rights to use, copy, modify, merge, publish,     #
# distribute, sublicense, and/or sell copies of the Software, and to      #
# permit persons to whom the Software is furnished to do so, subject to   #
# the following conditions:                                               #
#                                                                         #
# The above copyright notice and this permission notice shall be included #
# in all copies or substantial portions of the Software.                  #
#                                                                         #
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,         #
# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF      #
# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  #
# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY    #
# CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,    #
# TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE       #
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.                  #
###########################################################################

use CGI qw(:param);
use DBI;

require "lib/dbi-connect.pl";
require "lib/error.pl";
require "lib/date.pl";

#########################################################################################################
#
# Declare the local variables, print the content type, set the script variable, establish the database
# connection and print the header
#

local ($script,$dbh,$error,$search,$searchby,$nodisplay,$display,$id,$media,$reserve,$dyear,$dday,$results);
local ($title,$sg,$author,$description,$length,$rating,$system,$publisher,$year,$due,$dmonth,$sql,$sth);

print "Content-type: text/html\n\n";

$script = "search.cgi";
$dbh = dbiConnect($dbname);

print <<HTML;
<html>

<head>
	<title>Search Results</title>

	<style fprolloverstyle>
		A:hover {color: darkgreen; font-weight: bold}
	</style>
</head>

<body background="/images/background.gif" link="#800000" vlink="#C00000" alink="#000080">
HTML

#########################################################################################################
#
# Take the phrase and the column, make the search, and display the results.
#
#

if (param("search")) {
	$search = param("search");
	$searchby = param("searchby");

	$nodisplay = 0;

	if ($search eq "") {
		print qq|<h3 align="center">You forget to enter a search phrase.</h3>\n|;
		print qq|<h4 align="center">Press the back button to correct this.</h4>\n|;
		$nodisplay = 1;
	} else {
		$sql = "select id,media,title,sg,author,publisher,year,description,length,rating,system,due,reserve from catalog where lost = 0 and ${searchby} like ? order by media,author,title";
	}

	if ($nodisplay == 0) {
		$sth = $dbh->prepare($sql);
		$sth->execute("%${search}%");
		$error = $dbh->errstr;
		$results = $sth->rows;

		$display = "";

		while (($id,$media,$title,$sg,$author,$publisher,$year,$description,$length,$rating,$system,$due,$reserve) = $sth->fetchrow_array()) {
			$display .= qq|<center><table width="75%" border="1" bgcolor="#000000"><form method="POST" action="reserve.cgi"><input type="hidden" name="id" value="${id}">\n|;
			$display .= qq|<tr><td width="100%" bgcolor="#D3C1B6" align="center" colspan="2"><strong>${title}</strong></td></tr>\n|;
			$display .= qq|<tr><td width="20%" bgcolor="#D3C1B6" align="center">Catalog ID: </td><td width="80%" bgcolor="#D3C1B6">${id}</td></tr>\n|;

			if ($media == 1) {
				$display .= qq|<tr><td width="20%" bgcolor="#D3C1B6" align="center">Author: </td><td width="80%" bgcolor="#D3C1B6">${author}</td></tr>\n|;
				$display .= qq|<tr><td width="20%" bgcolor="#D3C1B6" align="center">Subject: </td><td width="80%" bgcolor="#D3C1B6">${sg}</td></tr>\n|;
				$display .= qq|<tr><td width="20%" bgcolor="#D3C1B6" align="center">Publisher: </td><td width="80%" bgcolor="#D3C1B6">${publisher}</td></tr>\n|;
				$display .= qq|<tr><td width="20%" bgcolor="#D3C1B6" align="center">Year of Publication: </td><td width="80%" bgcolor="#D3C1B6">${year}</td></tr>\n|;
			} elsif ($media == 2) {
				$display .= qq|<tr><td width="20%" bgcolor="#D3C1B6" align="center">Genre: </td><td width="80%" bgcolor="#D3C1B6">${sg}</td></tr>\n|;
				$display .= qq|<tr><td width="20%" bgcolor="#D3C1B6" align="center">Length: </td><td width="80%" bgcolor="#D3C1B6">${length}</td></tr>\n|;
				$display .= qq|<tr><td width="20%" bgcolor="#D3C1B6" align="center">Rating: </td><td width="80%" bgcolor="#D3C1B6">${rating}</td></tr>\n|;

				if ($system == 1) {
					$display .= qq|<tr><td width="20%" bgcolor="#D3C1B6" align="center">System: </td><td width="80%" bgcolor="#D3C1B6">VHS Videocasette</td></tr>\n|;
				} elsif ($system == 2) {
					$display .= qq|<tr><td width="20%" bgcolor="#D3C1B6" align="center">System: </td><td width="80%" bgcolor="#D3C1B6">DVD Disc</td></tr>\n|;
				}
			}

			$display .= qq|<tr><td width="20%" bgcolor="#D3C1B6" align="center">Description: </td><td width="80%" bgcolor="#D3C1B6">${description}</td></tr>\n|;

			if ($due != 0) {
				$dyear = substr($due,0,4);
				$dmonth = substr($due,4,2);
				$dday = substr($due,6,2);

				$dmonth = getMonthName($dmonth);

				$display .= qq|<tr><td width="20%" bgcolor="#D3C1B6" align="center">Status: </td><td width="80%" bgcolor="#D3C1B6">Checked Out Until ${dmonth} ${dday}, ${dyear}</td></tr>\n|;
			} elsif ($reserve != 0) {
				$display .= qq|<tr><td width="20%" bgcolor="#D3C1B6" align="center">Status: </td><td width="80%" bgcolor="#D3C1B6">Reserved</td></tr>\n|;
			} else {
				$display .= qq|<tr><td width="20%" bgcolor="#D3C1B6" align="center">Status: </td><td width="80%" bgcolor="#D3C1B6">Available</td></tr>\n|;
			}

			if ($reserve == 0) {
				$display .= qq|<tr><td width="100%" bgcolor="#D3C1B6" align="left" colspan="2"><input type="submit" value="Reserve This Book"></td></tr>\n|;
			}

			$display .= qq|</form></table></center><br>\n|;
		}
		$sth->finish;

		if ($error ne "") {
			handle($error,$script);
			die "Database Error: ${error}";
		}

		print qq|<h1 align="center">Search Results</h1>\n|;

		if ($results > 1 or $results == 0) {
			print qq|<h3 align="center">${results} Items Found.</h3>\n${display}\n|;
		} elsif ($results == 1) {
			print qq|<h3 align="center">${results} Item Found.</h3>\n${display}\n|;
		}

		print qq|<br><center><a href="search.html"><strong>Make Another Search</strong></a><br><br></center>\n|;
	}
}

print qq|<center><a href="index.html"><strong>Return to the Main Page</strong></a><br><img border="0" src="/images/book.gif" width="116" height="68"></center>\n</body>\n</html>\n|;

$dbh->disconnect;
