#!/usr/bin/perl

###########################################################################
#            Copyright (C) 2000 John David Ratliff                        #
#                                                                         #
# Permission is hereby granted, free of charge, to any person obtaining   #
# a copy of this software and associated documentation files (the         #
# "Software"), to deal in the Software without restriction, including     #
# without limitation the rights to use, copy, modify, merge, publish,     #
# distribute, sublicense, and/or sell copies of the Software, and to      #
# permit persons to whom the Software is furnished to do so, subject to   #
# the following conditions:                                               #
#                                                                         #
# The above copyright notice and this permission notice shall be included #
# in all copies or substantial portions of the Software.                  #
#                                                                         #
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,         #
# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF      #
# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  #
# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY    #
# CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,    #
# TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE       #
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.                  #
###########################################################################

use CGI qw(:param);
use DBI;

require "../lib/dbi-connect.pl";
require "../lib/error.pl";
require "../lib/date.pl";
require "../lib/checkout.pl";

#########################################################################################################
#
# Declare the local variables, print the content type, setup the script variable, establish the database
# connection and print the header.
#

local ($script,$dbh,$error,$email,$sth,$sql,$street,$books,$movies,$duedate);
local ($patron,$media,$reserve,$idgood,$confirm,$results,$id,$name,$nodisplay);

print "Content-type: text/html\n\n";

$script = "staff/checkout.cgi";
$dbh = dbiConnect($dbname);

print <<HTML;
<html>

<head>
	<title>Check an Item Out from the Library</title>

	<style fprolloverstyle>
		A:hover {color: darkgreen; font-weight: bold}
	</style>
</head>

<body background="/images/background.gif" link="#800000" vlink="#C00000" alink="#000080">
HTML

#########################################################################################################
#
# Find a patron's ID number based on his/her email address
#
#

if (param("findid")) {
	$email = param("email");

	$sql = "select id,name,street from patrons where email = ?";
	$sth = $dbh->prepare($sql);
	$sth->execute($email);
	$error = $dbh->errstr;
	($id,$name,$street) = $sth->fetchrow_array();
	$sth->finish;

	if ($error ne "") {
		handle($error,$script);
		die "Database Error: ${error}";
	}

	print qq|<h3 align="center">Patron's ID: ${id}<br>Name: ${name}<br>Street: ${street}</h3>\n|;

#########################################################################################################
#
# After checkouts are complete, mail the checkout list to the patron.
#
#

} elsif (param("maillist")) {
	$patron = param("patron");

	$sql = "select name,email from patrons where id = ?";
	$sth = $dbh->prepare($sql);
	$sth->execute($patron);
	$error = $dbh->errstr;
	($name,$email) = $sth->fetchrow_array();
	$sth->finish;

	if ($error ne "") {
		handle($error,$script);
		die "Database Error: ${error}";
	}

	$books = getBooks($patron);
	$movies = getMovies($patron);

	open(MAIL,"|/usr/sbin/sendmail ${email}");
	print MAIL "Content-type: text/html\n";
	print MAIL "To: ${name} <${email}>\n";
	print MAIL "From: Library Staff <${staffmail}>\n";
	print MAIL "Subject: Your Checkout List\n\n";
	print MAIL $books;
	print MAIL $movies;
	print MAIL qq|<br>Library Staff<br><a href="${staffmail}">${staffmail}</a><br><br>|;
	close(MAIL);

	print qq|<h3 align="center">Checkout List Mailed to ${name}</h3>\n|;

#########################################################################################################
#
# If checkout limit has been reached, but the staff member has chosen to override this, checkout the
# item to the patron anyway.
#

} elsif (param("confirm")) {
	$id = param("id");
	$patron = param("patron");
	$media = param("media");
	$reserve = param("reserve");

	if ($media == 1) {
		$sql = "select date_format(adddate(from_days(to_days(curdate())),interval 14 day),'%Y%m%d')";
	} elsif ($media == 2) {
		$sql = "select date_format(adddate(from_days(to_days(curdate())),interval 3 day),'%Y%m%d')";
	}

	$sth = $dbh->prepare($sql);
	$sth->execute();
	$duedate = $sth->fetchrow_array();
	$sth->finish;

	if ($error ne "") {
		handle($error,$script);
		die "Database Error: ${error}";
	}

	if ($patron == $reserve) {
		if ($media == 1) {
			$sql = "update catalog set patron = $patron, due = $duedate, rtime = 0, reserve = 0 where id = $id";
		} elsif ($media == 2) {
			$sql = "update catalog set patron = $patron, due = $duedate, rtime = 0, reserve = 0 where id = $id";
		}
	} else {
		if ($media == 1) {
			$sql = "update catalog set patron = $patron, due = $duedate, rtime = 0 where id = $id";
		} elsif ($media == 2) {
			$sql = "update catalog set patron = $patron, due = $duedate, rtime = 0, reserve = 0 where id = $id";
		}
	}

	$dbh->do($sql);
	$error = $dbh->errstr;

	if ($error ne "") {
		handle($error,$script);
		die "Database Error: ${error}";
	}

	$sql = "insert into history (uid,media,patron) values ($id,$media,$patron)";
	$dbh->do($sql);
	$error = $dbh->errstr;

	if ($error ne "") {
		handle($error,$script);
		die "Database Error: ${error}";
	}

	if ($media == 1) {
		print qq|<h3 align="center">Book Checked Out</h3>\n|;
	} elsif ($media == 2) {
		print qq|<h3 align="center">Movie Checked Out</h3>\n|;
	}

	$books = getBooks($patron);
	$movies = getMovies($patron);

	print qq|<h2 align="center">Checkout List</h2>\n|;
	print qq|<center><form method="POST" action="checkout.cgi"><input type="hidden" name="patron" value="${patron}"><input type="hidden" name="maillist" value="1"><input type="submit" value="E-Mail Checkout List to Patron"></form></center>\n|;
	print qq|${books}\n${movies}\n|;

#########################################################################################################
#
# Checkout an item to a patron using their ID number
#
#

} elsif (param()) {
	$id = param("id");
	$patron = param("patron");

	$id = int($id);

	$sql = "select media,reserve from catalog where id = ?";
	$sth = $dbh->prepare($sql);
	$sth->execute($id);
	$error = $dbh->errstr;
	($media,$reserve) = $sth->fetchrow_array();
	$idgood = $sth->rows;
	$sth->finish;

	if ($error ne "") {
		handle($error,$script);
		die "Database Error: ${error}";
	}

	if ($media == 1) {
		$sql = "select date_format(adddate(from_days(to_days(curdate())),interval 14 day),'%Y%m%d')";
	} elsif ($media == 2) {
		$sql = "select date_format(adddate(from_days(to_days(curdate())),interval 3 day),'%Y%m%d')";
	}

	$sth = $dbh->prepare($sql);
	$sth->execute();
	$duedate = $sth->fetchrow_array();
	$sth->finish;

	if ($error ne "") {
		handle($error,$script);
		die "Database Error: ${error}";
	}

	$sql = "select confirm from patrons where id = ?";
	$sth = $dbh->prepare($sql);
	$sth->execute($patron);
	$error = $dbh->errstr;
	$confirm = $sth->fetchrow_array();
	$sth->finish;

	if ($error ne "") {
		handle($error,$script);
		die "Database Error: ${error}";
	}

	if ($confirm == 1 && $idgood == 1) {
		if ($media == 1) {
			$sql = "select id from catalog where patron = $patron and id != $id and media = 1";
			$results = $dbh->do($sql);
			$error = $dbh->errstr;

			if ($error ne "") {
				handle($error,$script);
				die "Database Error: ${error}";
			}

			if ($results < 5) {
				if ($reserve == $patron) {
					$sql = "update catalog set patron = $patron, due = $duedate, rtime = 0, reserve = 0 where id = $id";
				} else {
					$sql = "update catalog set patron = $patron, due = $duedate, rtime = 0 where id = $id";
				}

				$dbh->do($sql);
				$error = $dbh->errstr;

				if ($error ne "") {
					handle($error,$script);
					die "Database Error: ${error}";
				}

				$sql = "insert into history (uid,media,patron) values ($id,$media,$patron)";
				$dbh->do($sql);
				$error = $dbh->errstr;

				if ($error ne "") {
					handle($error,$script);
					die "Database Error: ${error}";
				}

				print qq|<h3 align="center">Book Checked Out</h3>\n|;
			} else {
				print qq|<h3 align="center">Book Limit Reached. Please Confirm Checkout.</h3>\n|;
				print qq|<center><form method="POST" action="checkout.cgi"><input type="hidden" name="confirm" value="1"><input type="hidden" name="reserve" value="${reserve}"><input type="hidden" name="patron" value="${patron}"><input type="hidden" name="id" value="${id}"><input type="hidden" name="media" value="${media}"><input type="submit" value="Confirm Checkout"></form></center>\n|;
			}
		} elsif ($media == 2) {
			$sql = "select id from catalog where patron = $patron and id != $id and media = 2";
			$results = $dbh->do($sql);
			$error = $dbh->errstr;

			if ($error ne "") {
				handle($error,$script);
				die "Database Error: ${error}";
			}

			if ($results < 2) {
				if ($patron == $reserve) {
					$sql = "update catalog set patron = $patron, due = $duedate, rtime = 0, reserve = 0 where id = $id";
				} else {
					$sql = "update catalog set patron = $patron, due = $duedate, rtime = 0 where id = $id";
				}

				$dbh->do($sql);
				$error = $dbh->errstr;

				if ($error ne "") {
					handle($error,$script);
					die "Database Error: ${error}";
				}

				$sql = "insert into history (uid,media,patron) values ($id,$media,$patron)";
				$dbh->do($sql);
				$error = $dbh->errstr;

				if ($error ne "") {
					handle($error,$script);
					die "Database Error: ${error}";
				}

				print qq|<h3 align="center">Movie Checked Out</h3>\n|;
			} else {
				print qq|<h3 align="center">Movie Limit Reached. Please Confirm Checkout.</h3>\n|;
				print qq|<center><form method="POST" action="checkout.cgi"><input type="hidden" name="confirm" value="1"><input type="hidden" name="reserve" value="${reserve}"><input type="hidden" name="patron" value="${patron}"><input type="hidden" name="id" value="${id}"><input type="hidden" name="media" value="${media}"><input type="submit" value="Confirm Checkout"></form></center>\n|;
			}
		}

		$books = getBooks($patron);
		$movies = getMovies($patron);

		print qq|<h2 align="center">Checkout List</h2>\n|;
		print qq|<center><form method="POST" action="checkout.cgi"><input type="hidden" name="patron" value="${patron}"><input type="hidden" name="maillist" value="1"><input type="submit" value="E-Mail Checkout List to Patron"></form></center>\n|;
		print qq|${books}\n${movies}\n|;
	} else {
		print qq|<h3 align="center">Invalid Item or Account, or the Account has not been Confirmed. Cannot Check Items Out.</h3>\n|;
	}
}

#########################################################################################################
#
# Print the checkout form.
#
#

print <<HTML;
<h1 align="center">Library Check-Out System</h1>

<center>
	<form method="POST" action="checkout.cgi">
		<table width="75%" border="1" bgcolor="#000000">
			<tr>
				<td width="100%" colspan="2" align="center" bgcolor="#D3C1B6"><strong>Checkout an Item</strong></td>
			</tr>

			<tr>
				<td width="20%" bgcolor="#D3C1B6" align="center">Catalog ID: </td>
				<td width="80%" bgcolor="#D3C1B6"><input type="text" name="id" size="5"> <font size="-1"><a href="../search.html" target="_blank">Find Catalog ID Number</a></font></td>
			</tr>

			<tr>
				<td width="20%" bgcolor="#D3C1B6" align="center">Patron ID: </td>
				<td width="80%" bgcolor="#D3C1B6"><input type="text" name="patron" size="5"> <font size="-1"><a href="#patron">Find Patron ID</a></font></td>
			</tr>

			<tr>
				<td width="100%" colspan="2" align="left" bgcolor="#D3C1B6"><input type="submit" value="Check Item Out"></td>
			</tr>
		</table>
	</form>

	<hr width="50%" color="#A00000">

	<a name="patron">
		<form method="POST" action="checkout.cgi">
			<input type="hidden" name="findid" value="1">

			<table width="75%" border="1" bgcolor="#000000">
				<tr>
					<td width="100%" colspan="2" align="center" bgcolor="#D3C1B6"><strong>Find Patron ID</strong></td>
				</tr>

				<tr>
					<td width="20%" align="center" bgcolor="#D3C1B6">Patron E-Mail: </td>
					<td width="80%" bgcolor="#D3C1B6"><input type="text" name="email" size="30"></td>
				</tr>

				<tr>
					<td width="100%" colspan="2" align="left" bgcolor="#D3C1B6"><input type="submit" value="Find Patron ID"></td>
				</tr>
			</table>
		</form>
	</a>
</center>
HTML

print <<HTML;
<center>
	<a href="index.html"><strong>Return to the Staff Page</strong></a>
	<br><img border="0" src="/images/book.gif" width="116" height="68">
	
	<p><h5>
		Web design by Jennifer Joy Hawkins
		<br>Copyright (C) 2000 Jennifer Joy Hawkins
		<br>All Rights Reserved
	</h5></p>
</center>
</body>

</html>
HTML

$dbh->disconnect;
