#!/usr/bin/perl

###########################################################################
#            Copyright (C) 2000 John David Ratliff                        #
#                                                                         #
# Permission is hereby granted, free of charge, to any person obtaining   #
# a copy of this software and associated documentation files (the         #
# "Software"), to deal in the Software without restriction, including     #
# without limitation the rights to use, copy, modify, merge, publish,     #
# distribute, sublicense, and/or sell copies of the Software, and to      #
# permit persons to whom the Software is furnished to do so, subject to   #
# the following conditions:                                               #
#                                                                         #
# The above copyright notice and this permission notice shall be included #
# in all copies or substantial portions of the Software.                  #
#                                                                         #
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,         #
# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF      #
# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  #
# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY    #
# CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,    #
# TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE       #
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.                  #
###########################################################################

use CGI qw(:param);
use DBI;

require "../lib/dbi-connect.pl";
require "../lib/error.pl";

#########################################################################################################
#
# Declare the local variables, print the content type, set the script variable, establish the database
# connection and print the header
#

local ($script,$dbh,$error,$id,$name,$email,$feedback,$response,$sql,$sth,$nodisplay);

print "Content-type: text/html\n\n";

$script = "staff/feedback.cgi";
$dbh = dbiConnect($dbname);

print <<HTML;
<html>

<head>
	<title>Read User's Feedback</title>

	<style fprolloverstyle>
		A:hover {color: darkgreen; font-weight: bold}
	</style>
</head>

<body background="/images/background.gif" link="#800000" vlink="#C00000" alink="#000080">
HTML

#########################################################################################################
#
# This part takes the staff's response and mails it to user with a copy sent to the staff for reference.
#
#

if (param("confirm")) {
	$id = param("id");
	$name = param("name");
	$email = param("email");
	$feedback = param("feedback");
	$response = param("response");

	$sql = "update feedback set status = 1, response = ? where id = ?";
	$sth = $dbh->prepare($sql);
	$sth->execute($response,$id);
	$error = $dbh->errstr;
	$sth->finish;

	if ($error ne "") {
		handle($error,$script);
		die "Database Error: ${error}";
	}

	open(MAIL,"|/usr/sbin/sendmail ${email} ${staffmail}");
	print MAIL "To: ${name} <${email}>\n";
	print MAIL "From: Library Staff <${staffmail}>\n";
	print MAIL "Subject: Feedback Response\n\n";
	print MAIL "${response}\n\nYour Feedback:\n\n${feedback}\n\nLibrary Staff\n${staffmail}\n\n";
	close(MAIL);

	print qq|<h3 align="center">Your response has been sent to the user, with a copy mailed to the staff account.</h3>\n|;

	print "<br><br>\n\n";

#########################################################################################################
#
# Once the feedback is selected from the form, print the entire message and allow the staff to respond or
# delete the feedback, depending upon the selection made in the last form.
#

} elsif (param()) {
	$id = param("id");
	$action = param("action");

	if ($action == 1) {
		$sql = "select name,email,feedback,response from feedback where id = ?";
		$sth = $dbh->prepare($sql);
		$sth->execute($id);
		$error = $dbh->errstr;
		$results = $sth->rows;
		($name,$email,$feedback,$response) = $sth->fetchrow_array();
		$sth->finish;

		if ($error ne "") {
			handle($error,$script);
			die "Database Error: ${error}";
		}

		if ($results == 1) {
			print qq|<h1 align="center">Reply to ${name}'s Feedback</h1>\n|;

			print qq|<center><table width="75%" border="1" bgcolor="#000000"><form method="GET" action="feedback.cgi">\n|;
			print qq|<input type="hidden" name="confirm" value="1"><input type="hidden" name="id" value="${id}"><input type="hidden" name="name" value="${name}"><input type="hidden" name="email" value="${email}"><input type="hidden" name="feedback" value="${feedback}">\n|;
			print qq|<tr><td width="20%" bgcolor="#D3C1B6" align="center">Name: </td><td width="80%" bgcolor="#D3C1B6">${name}</td></tr>\n|;
			print qq|<tr><td width="20%" bgcolor="#D3C1B6" align="center">E-Mail: </td><td width="80%" bgcolor="#D3C1B6">${email}</td></tr>\n|;
			print qq|<tr><td width="20%" bgcolor="#D3C1B6" align="center">Feedback: </td><td width="80%" bgcolor="#D3C1B6">${feedback}</td></tr>\n|;
			print qq|<tr><td width="20%" bgcolor="#D3C1B6" align="center">Response: </td><td width="80%" bgcolor="#D3C1B6"><textarea name="response" rows="7" cols="40">${response}</textarea></td></tr>\n|;
			print qq|<tr><td width="100%" bgcolor="#D3C1B6" colspan="2"><input type="submit" value="Reply to ${name}"></td></tr>\n|;
			print qq|</form></table></center>\n\n|;

			$nodisplay = 1;
		} else {
			print qq|<h2 align="center">There is no feedback with that ID number in the database.</h2><br><br>\n|;
		}
	} elsif ($action == 2) {
		$sql = "update feedback set status = 2 where id = $id";
		$dbh->do($sql);
		$error = $dbh->errstr;

		if ($error ne "") {
			handle($error,$script);
			die "Database Error: ${error}";
		}

		print qq|<h2 align="center">Deleted Patron's Feedback</h2><br><br>\n|;
	} else {
		print qq|<h2 align="center">No Action Specified</h2><br><br>\n|;
	}
}

#########################################################################################################
#
# Unless we're told not to, print all the feedback in the database and allow the staff to look at it all.
#
#

if ($nodisplay != 1) {
	$sql = "select id,name,email,feedback,response from feedback where status != 2 order by id desc";
	$sth = $dbh->prepare($sql);
	$sth->execute();
	$results = $sth->rows;
	$error = $dbh->errstr;

	$display = "";

	while (($id,$name,$email,$feedback,$response) = $sth->fetchrow_array()) {
		$display .= qq|<center><table width="75%" border="1" bgcolor="#000000"><form method="GET" action="feedback.cgi"><input type="hidden" name="id" value="${id}">\n|;
		$display .= qq|<tr><td width="20%" bgcolor="#D3C1B6" align="center">Name: </td><td width="80%" bgcolor="#D3C1B6">${name}</td></tr>\n|;
		$display .= qq|<tr><td width="20%" bgcolor="#D3C1B6" align="center">E-Mail: </td><td width="80%" bgcolor="#D3C1B6">${email}</td></tr>\n|;
		$display .= qq|<tr><td width="20%" bgcolor="#D3C1B6" align="center">Feedback: </td><td width="80%" bgcolor="#D3C1B6">${feedback}</td></tr>\n|;
		$display .= qq|<tr><td width="20%" bgcolor="#D3C1B6" align="center">Response: </td><td width="80%" bgcolor="#D3C1B6">${response}</td></tr>\n|;
		$display .= qq|<tr><td width="100%" bgcolor="#D3C1B6" align="left" colspan="2"><select name="action" height="1"><option value="1">Reply to this Feedback</option><option value="2">Delete this Feedback</option></select> <input type="submit" value="Submit"></td></tr>\n|;
		$display .= qq|</form></table></center><br>\n\n|;
	}
	$sth->finish;

	if ($error ne "") {
		handle($error,$script);
		die "Database Error: ${error}";
	}

	if ($results == 0) {
		print qq|<h1 align="center">There is no feedback in the database.</h1>|;
	} else {
		print qq|<h1 align="center">Read User's Feedback</h1>\n${display}|;
	}
}

print <<HTML;
<center>
	<a href="index.html"><strong>Return to the Staff Page</strong></a>
	<br><img border="0" src="/images/book.gif" width="116" height="68">
	
	<p><h5>
		Web design by Jennifer Joy Hawkins
		<br>Copyright (C) 2000 Jennifer Joy Hawkins
		<br>All Rights Reserved
	</h5></p>
</center>
</body>

</html>
HTML

$dbh->disconnect;
