#!/usr/bin/perl

###########################################################################
#            Copyright (C) 2000 John David Ratliff                        #
#                                                                         #
# Permission is hereby granted, free of charge, to any person obtaining   #
# a copy of this software and associated documentation files (the         #
# "Software"), to deal in the Software without restriction, including     #
# without limitation the rights to use, copy, modify, merge, publish,     #
# distribute, sublicense, and/or sell copies of the Software, and to      #
# permit persons to whom the Software is furnished to do so, subject to   #
# the following conditions:                                               #
#                                                                         #
# The above copyright notice and this permission notice shall be included #
# in all copies or substantial portions of the Software.                  #
#                                                                         #
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,         #
# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF      #
# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  #
# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY    #
# CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,    #
# TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE       #
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.                  #
###########################################################################

use CGI qw(:param);
use DBI;

require "../lib/dbi-connect.pl";
require "../lib/error.pl";

#########################################################################################################
#
# Declare the local variables, print the content type, set the script variable, establish the database
# connection and print the header
#

local ($script,$dbh,$error,$results,$display,$sql,$sth,$id,$title,$sth2,$sg);
local ($author,$publisher,$year,$description,$ltime,$rating,$length,$system,$media);

print "Content-type: text/html\n\n";

$script = "staff/lost.cgi";
$dbh = dbiConnect($dbname);

print <<HTML;
<html>

<head>
	<title>Examine the Lost Item List</title>

	<style fprolloverstyle>
		A:hover {color: darkgreen; font-weight: bold}
	</style>
</head>

<body background="/images/background.gif" link="#800000" vlink="#C00000" alink="#000080">
HTML

#########################################################################################################
#
# Get the list of lost items in order of most recently lost sorted by media type.
# If any exist, print the list.
#

$display = "";

$sql = "select id,media,title,author,sg,publisher,year,description,rating,length,system,ltime from catalog where lost = 1 order by media asc,ltime desc";
$sth = $dbh->prepare($sql);
$sth->execute();
$results = $sth->rows;
$error = $dbh->errstr;

while (($id,$media,$title,$author,$sg,$publisher,$year,$description,$rating,$length,$system,$ltime) = $sth->fetchrow_array()) {
	$sql = "select date_format($ltime,'%W, %M %e, %Y')";
	$sth2 = $dbh->prepare($sql);
	$sth2->execute();
	$error = $dbh->errstr;
	$ltime = $sth2->fetchrow_array();
	$sth2->finish;

	if ($error ne "") {
		handle($error,$script);
		die "Database Error: ${error}";
	}

	$display .= qq|<center><table width="75%" border="1" bgcolor="#000000">\n|;
	$display .= qq|<tr><td width="100%" bgcolor="#D3C1B6" align="center" colspan="2"><strong>${title}</strong></td></tr>\n|;
	$display .= qq|<tr><td width="20%" bgcolor="#D3C1B6" align="center">Catalog ID: </td><td width="80%" bgcolor="#D3C1B6">${id}</td></tr>\n|;

	if ($media == 1) {
		$display .= qq|<tr><td width="20%" bgcolor="#D3C1B6" align="center">Author: </td><td width="80%" bgcolor="#D3C1B6">${author}</td></tr>\n|;
		$display .= qq|<tr><td width="20%" bgcolor="#D3C1B6" align="center">Subject: </td><td width="80%" bgcolor="#D3C1B6">${sg}</td></tr>\n|;
		$display .= qq|<tr><td width="20%" bgcolor="#D3C1B6" align="center">Publisher: </td><td width="80%" bgcolor="#D3C1B6">${publisher}</td></tr>\n|;
		$display .= qq|<tr><td width="20%" bgcolor="#D3C1B6" align="center">Year of Publication: </td><td width="80%" bgcolor="#D3C1B6">${year}</td></tr>\n|;
	} elsif ($media == 2) {
		$display .= qq|<tr><td width="20%" bgcolor="#D3C1B6" align="center">Genre: </td><td width="80%" bgcolor="#D3C1B6">${sg}</td></tr>\n|;
		$display .= qq|<tr><td width="20%" bgcolor="#D3C1B6" align="center">Rating: </td><td width="80%" bgcolor="#D3C1B6">${rating}</td></tr>\n|;
		$display .= qq|<tr><td width="20%" bgcolor="#D3C1B6" align="center">Length: </td><td width="80%" bgcolor="#D3C1B6">${length}</td></tr>\n|;

		if ($system == 1) {
			$display .= qq|<tr><td width="20%" bgcolor="#D3C1B6" align="center">System: </td><td width="80%" bgcolor="#D3C1B6">VHS Videocasette</td></tr>\n|;
		} elsif ($system == 2) {
			$display .= qq|<tr><td width="20%" bgcolor="#D3C1B6" align="center">System: </td><td width="80%" bgcolor="#D3C1B6">DVD Disc</td></tr>\n|;
		}
	}

	$display .= qq|<tr><td width="20%" bgcolor="#D3C1B6" align="center">Description: </td><td width="80%" bgcolor="#D3C1B6">${description}</td></tr>\n|;
	$display .= qq|<tr><td width="20%" bgcolor="#D3C1B6" align="center">Missing Since: </td><td width="80%" bgcolor="#D3C1B6">${ltime}</td></tr>\n|;
	$display .= qq|</table></center><br>\n\n|;
}
$sth->finish;

if ($error ne "") {
	handle($error,$script);
	die "Database Error: ${error}";
}

if ($results == 0) {
	print qq|<h3 align="center">No Lost Items</h3>\n|;
} else {
	print qq|<h1 align="center">The Lost Item List</h1>\n${display}|;
}

print <<HTML;
<center>
	<a href="index.html"><strong>Return to the Staff Page</strong></a>
	<br><img border="0" src="/images/book.gif" width="116" height="68">
	
	<p><h5>
		Web design by Jennifer Joy Hawkins
		<br>Copyright (C) 2000 Jennifer Joy Hawkins
		<br>All Rights Reserved
	</h5></p>
</center>
</body>

</html>
HTML

$dbh->disconnect;
