#!/usr/bin/perl

###########################################################################
#            Copyright (C) 2000 John David Ratliff                        #
#                                                                         #
# Permission is hereby granted, free of charge, to any person obtaining   #
# a copy of this software and associated documentation files (the         #
# "Software"), to deal in the Software without restriction, including     #
# without limitation the rights to use, copy, modify, merge, publish,     #
# distribute, sublicense, and/or sell copies of the Software, and to      #
# permit persons to whom the Software is furnished to do so, subject to   #
# the following conditions:                                               #
#                                                                         #
# The above copyright notice and this permission notice shall be included #
# in all copies or substantial portions of the Software.                  #
#                                                                         #
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,         #
# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF      #
# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  #
# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY    #
# CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,    #
# TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE       #
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.                  #
###########################################################################

use DBI;

require "../lib/dbi-connect.pl";
require "../lib/error.pl";

####################################################################################################
#
# setup the local and global variables and initilize the log variable.
# establish the database connection.
#

local ($script,$dbh,$error,$log,$sql,$sth,$now,$id,$time,$then,$sth2,$name,$email);
local ($media,$patron,$due,$fines,$reserve,$rtime,$title,$author,$description);

$script = "staff/maintenance.pl";
$dbh = dbiConnect($dbname);

$log = "";

####################################################################################################
#
# get the current time in strict numeric format (Midnight, Jan 1, 1970 = 19700101000000)
#

$sql = "select date_format(from_days(to_days(now())),'%Y%m%d%I%i%s')";
$sth = $dbh->prepare($sql);
$sth->execute();
$error = $dbh->errstr;
$now = $sth->fetchrow_array();
$sth->finish;

if ($error ne "") {
	handle($error,$script);
	die "Database Error: ${error}";
}

####################################################################################################
#
# check for unconfirmed accounts
#

$sql = "select id,time from patrons where confirm = 0";
$sth = $dbh->prepare($sql);
$sth->execute();
$error = $dbh->errstr;

while (($id,$time) = $sth->fetchrow_array()) {

				## THIS GETS THE DATE 7 DAYS FROM THE TIME OF THE ACCOUNT'S CREATION IN NUMERIC FORMAT

		$sql = "select date_format(adddate(from_days(to_days($time)),interval 7 day),'%Y%m%d%I%i%s')";
		$sth2 = $dbh->prepare($sql);
		$sth2->execute();
		$error = $dbh->errstr;
		$then = $sth2->fetchrow_array();
		$sth2->finish;

		if ($error ne "") {
			handle($error,$script);
			die "Database Error: ${error}";
		}

		if ($then < $now) {
				## CANCEL THE ACCOUNT IF LEFT UNCONFIRMED FOR MORE THAN ONE WEEK

			$sql = "select name,email from patrons where id = ?";
			$sth2 = $dbh->prepare($sql);
			$sth2->execute($id);
			$error = $dbh->errstr;
			($name,$email) = $sth2->fetchrow_array();
			$sth2->finish;

			if ($error ne "") {
				handle($error,$script);
				die "Database Error: ${error}";
			}

			open(MAIL,"|/usr/sbin/sendmail ${email}");
			print MAIL "To: $name <${email}>\n";
			print MAIL "From: Library Staff <${staffmail}>\n";
			print MAIL "Subject: Account Cancelled\n\n";
			print MAIL "Your account has been cancelled as you did not confirm it.\n";
			print MAIL "If you did not sign up for an online library account, please disregard this email.\n";
			print MAIL "\nLibrary Staff\n${staffmail}\n\n";
			close(MAIL);

			$sql = "delete from patrons where id = $id";
			$dbh->do($sql);
			$error = $dbh->errstr;

			if ($error ne "") {
				handle($error,$script);
				die "Database Error: ${error}";
			}

			$log .= "Unconfirmed Account Expired: ${id}\n";
		}
}
$sth->finish;

if ($error ne "") {
	handle($error,$script);
	die "Database Error: ${error}";
}

####################################################################################################
#
# check for overdue items and assess late fines for items that are SIGNIFICANTLY overdue
#

$sql = "select id,patron,due,media from catalog where due != 0 and lost = 0";
$sth = $dbh->prepare($sql);
$sth->execute();
$error = $dbh->errstr;

while (($id,$patron,$due,$media) = $sth->fetchrow_array()) {
	$sql = "select name,email,fines from patrons where id = ?";
	$sth2 = $dbh->prepare($sql);
	$sth2->execute($patron);
	$error = $dbh->errstr;
	($name,$email,$fines) = $sth2->fetchrow_array();
	$sth2->finish;

	if ($error ne "") {
		handle($error,$script);
		die "Database Error: ${error}";
	}

	$sql = "select title from catalog where id = ?";
	$sth2 = $dbh->prepare($sql);
	$sth2->execute($id);
	$error = $dbh->errstr;
	$title = $sth2->fetchrow_array();
	$sth2->finish;

	if ($error ne "") {
		handle($error,$script);
		die "Database Error: ${error}";
	}

	$due = "${due}120000";

	if ($now > $due) {
		open(MAIL,"|/usr/sbin/sendmail ${email}");
		print MAIL "To: ${name} <${email}>\n";
		print MAIL "From: Library Staff <${staffmail}>\n";
		print MAIL "Subject: Overdue Item Notice\n\n";
		print MAIL "The item you checked out: ${title} is now overdue. Please return it as soon as possible.\n";
		print MAIL "If it becomes more than a week late (or 3 days for movies), you will be assessed late fines.\n";
		print MAIL "We appreciate your responsible patronage.\n";
		print MAIL "\nLibrary Staff\n${staffmail}\n\n";
		close(MAIL);

		$log .= "Sent overdue notice to ${name} for item ${title} (ID: ${id})\n";
	}

	if ($media == 1) {
		$sql = "select date_format(adddate(from_days(to_days($due)),interval 7 day),'%Y%m%d%I%i%s')";
	} elsif ($media == 2) {
		$sql = "select date_format(adddate(from_days(to_days($due)),interval 3 day),'%Y%m%d%I%i%s')";
	}

	$sth2 = $dbh->prepare($sql);
	$sth2->execute();
	$error = $dbh->errstr;
	$due = $sth2->fetchrow_array();
	$sth2->finish;

	if ($error ne "") {
		handle($error,$script);
		die "Database Error: ${error}";
	}

	if ($now > $due) {
		if ($media == 1) {
			$fines+=0.10;
			$log .= "Fined Patron ${patron} \$0.10 for Overdue Book (ID: ${id})\n";
		} elsif ($media == 2) {
			$fines+=1.00;
			$log .= "Fined Patron ${patron} \$1.00 for Overdue Movie (ID: ${id})\n";
		}

		$sql = "update patrons set fines = $fines where id = $patron";
		$dbh->do($sql);
		$error = $dbh->errstr;

		if ($error ne "") {
			handle($error,$script);
			die "Database Error: ${error}";
		}

		open(MAIL,"|/usr/sbin/sendmail ${email}");
		print MAIL "To: ${name} <${email}>\n";
		print MAIL "From: Library Staff <${staffmail}>\n";
		print MAIL "Subject: Late Fines Assessed\n\n";

		if ($media == 1) {
			print MAIL "You have been fined \$0.10 for your overdue book ${title}.\n";
		} elsif ($media == 2) {
			print MAIL "You have been fined \$1.00 for your overdue movie ${title}.\n";
		}

		print MAIL "\nLibrary Staff\n${staffmail}\n\n";
		close(MAIL);
	}

	$sql = "select date_format(adddate(from_days(to_days($due)),interval 90 day),'%Y%m%d%I%i%s')";

	$sth2 = $dbh->prepare($sql);
	$sth2->execute();
	$error = $dbh->errstr;
	$due = $sth2->fetchrow_array();
	$sth2->finish;

	if ($error ne "") {
		handle($error,$script);
		die "Database Error: ${error}";
	}

	if ($now > $due) {
		$log .= "Patron ${name} (ID: ${patron}) is being assessed a replacement cost for lost item ${title} (ID: ${id}).\n";

		$sql = "update catalog set lost = 1, ltime = NULL where id = $id";
		$dbh->do($sql);
		$error = $dbh->errstr;

		if ($error ne "") {
			handle($error,$script);
			die "Database Error: ${error}";
		}

		open(MAIL,"|/usr/sbin/sendmail ${staffmail}");
		print MAIL "To: Library Staff <${staffmail}>\n";
		print MAIL "From: Maintenance Script <${staffmail}>\n";
		print MAIL "Subject: Lost Item\n\n";
		print MAIL "Item Number ${id} is now more than 90 days overdue and is considered lost.\n";
		print MAIL "The patron ${name} has been notified by email that he or she is being assessed a replacement cost.\n";
		print MAIL "To access this patrons information, please consult the patron information form ${server}/staff/patron.cgi?id=${patron}\n";
		print MAIL "The item has been removed from the catalog. This information can also be found in the maintenance log.\n";
		print MAIL "\nMaintenance Script\n${staffmail}\n\n";
		close(MAIL);

		open(MAIL,"|/usr/sbin/sendmail ${email}");
		print MAIL "To: ${name} <${email}>\n";
		print MAIL "From: Library Staff <${staffmail}>\n";
		print MAIL "Subject: Late Fines Assessed\n\n";

		if ($media == 1) {
			print MAIL "You are being assessed a replacement cost for the book ${title}.\n";
		} elsif ($media == 2) {
			print MAIL "You are being assessed a replacement cose for the movie ${title}.\n";
		}

		print MAIL "\nLibrary Staff\n${staffmail}\n\n";
		close(MAIL);
	}
}
$sth->finish;

if ($error ne "") {
	handle($error,$script);
	die "Database Error: ${error}";
}

####################################################################################################
#
# check for expired reservations
#

$sql = "select id,reserve,rtime from catalog where reserve != 0 and rtime != 0";
$sth = $dbh->prepare($sql);
$sth->execute();
$error = $dbh->errstr;

while (($id,$reserve,$rtime) = $sth->fetchrow_array()) {
	$sql = "select date_format(adddate(from_days(to_days($rtime)),interval 7 day),'%Y%m%d%I%i%s')";
	$sth2 = $dbh->prepare($sql);
	$sth2->execute();
	$error = $dbh->errstr;
	$rtime = $sth2->fetchrow_array();
	$sth2->finish;

	if ($error ne "") {
		handle($error,$script);
		die "Database Error: ${error}";
	}

	if ($now > $rtime) {
		$sql = "update catalog set reserve = 0, rtime = 0 where id = $id";
		$dbh->do($sql);
		$error = $dbh->errstr;

		if ($error ne "") {
			handle($error,$script);
			die "Database Error: ${error}";
		}

		$log .= "Reservation Expired on Item ID: ${id}\n";

		$sql = "select name,email from patrons where id = ?";
		$sth2 = $dbh->prepare($sql);
		$sth2->execute($reserve);
		$error = $dbh->errstr;
		($name,$email) = $sth2->fetchrow_array();
		$sth2->finish;

		if ($error ne "") {
			handle($error,$script);
			die "Database Error: ${error}";
		}

		$sql = "select title,author,description from catalog where id = ?";
		$sth2 = $dbh->prepare($sql);
		$sth2->execute($id);
		$error = $dbh->errstr;
		($title,$author,$description) = $sth2->fetchrow_array();
		$sth2->finish;

		if ($error ne "") {
			handle($error,$script);
			die "Database Error: ${error}";
		}

		open(MAIL,"|/usr/sbin/sendmail ${email} ${staffmail}");
		print MAIL "To: ${name} <${email}>\n";
		print MAIL "From: Library Staff <${staffmail}>\n";
		print MAIL "Subject: Reservation for ${title} cancelled.\n\n";
		print MAIL "Your reservation has been cancelled because your time to pickup the item has expired.\n";
		print MAIL "\nTitle: ${title}\n";

		if ($author ne "") {
			print MAIL "Author: ${author}\n";
		}

		print MAIL "Description: ${description}\n";
		print MAIL "\nLibrary Staff\n${staffmail}\n\n";

		print MAIL "P.S. Please note that our reservation policy is to hold items for 7 days and then return them to the shelves.\n";
		close(MAIL);
	}
}
$sth->finish;

if ($error ne "") {
	handle($error,$script);
	die "Database Error: ${error}";
}

####################################################################################################
#
# if we actually had to do something, record it in the log file and mail the administrator.
#

if ($log ne "") {
	(@ctime) = localtime(time);
	$ctime[5]+=1900;
	$ctime[4]++;

	open(LOG,">>${fullpath}/staff/dailylog.txt");
	print LOG "\n\n---------------------------------------------------------------------------------------\n";
	print LOG "		    Log File for $ctime[4]-$ctime[3]-$ctime[5]\n";
	print LOG "---------------------------------------------------------------------------------------\n\n";
	print LOG $log;
	close(LOG);

	open(MAIL,"|/usr/sbin/sendmail ${adminmail}");
	print MAIL "To: Library Administrator <${adminmail}>\n";
	print MAIL "From: Maintenance Script <${staffmail}>\n";
	print MAIL "Subject: Daily Library Maintenance Log\n\n";
	print MAIL "The complete log can be found in the staff directory in a file name dailylog.txt\n\n";
	print MAIL $log;
	close(MAIL);
}

$dbh->disconnect;
