#!/usr/bin/perl

###########################################################################
#            Copyright (C) 2000 John David Ratliff                        #
#                                                                         #
# Permission is hereby granted, free of charge, to any person obtaining   #
# a copy of this software and associated documentation files (the         #
# "Software"), to deal in the Software without restriction, including     #
# without limitation the rights to use, copy, modify, merge, publish,     #
# distribute, sublicense, and/or sell copies of the Software, and to      #
# permit persons to whom the Software is furnished to do so, subject to   #
# the following conditions:                                               #
#                                                                         #
# The above copyright notice and this permission notice shall be included #
# in all copies or substantial portions of the Software.                  #
#                                                                         #
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,         #
# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF      #
# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  #
# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY    #
# CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,    #
# TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE       #
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.                  #
###########################################################################

use CGI qw(:param);
use DBI;

require "../lib/dbi-connect.pl";
require "../lib/error.pl";

#########################################################################################################
#
# Declare the local variables, print the content type, setup the script variable, establish the database
# connection, and print the header
#

local ($script,$dbh,$error,$media,$title,$sg,$author,$publisher);
local ($rating,$length,$system,$sql,$sth,$year,$description);

print "Content-type: text/html\n\n";

$script = "staff/newmedia.cgi";
$dbh = dbiConnect($dbname);

print <<HTML;
<html>

<head>
	<title>Library Database Updater</title>

	<style fprolloverstyle>
		A:hover {color: darkgreen; font-weight: bold}
	</style>
</head>

<body background="/images/background.gif" link="#800000" vlink="#C00000" alink="#000080">
HTML

#########################################################################################################
#
# Add entry to catalog. Books have media == 1, Movies have media == 2.
#
#

if (param("media")) {
	$media = param("media");

	if ($media == 1) {
		$title = param("title");
		$sg = param("sg");
		$author = param("author");
		$publisher = param("publisher");
		$year = param("year");
		$description = param("description");

		if ($title eq "" or $sg eq "" or $author eq "" or $publisher eq "" or $year eq "" or $description eq "") {
			print qq|<h3 align="center">You forgot to fill in one of the form elements.</h3><br>\n|;
		} else {
			$sql = "insert into catalog (media,title,author,sg,publisher,year,description) values (?,?,?,?,?,?,?)";
			$sth = $dbh->prepare($sql);
			$sth->execute($media,$title,$author,$sg,$publisher,$year,$description);
			$error = $dbh->errstr;
			$sth->finish;

			if ($error ne "") {
				handle($error,$script);
				die "Database Error: ${error}";
			}

			print qq|<h3 align="center">Entry Successful!</h3><br>\n|;
		}
	} elsif ($media == 2) {
		$title = param("title");
		$sg = param("sg");
		$rating = param("rating");
		$length = param("length");
		$description = param("description");
		$system = param("system");

		if ($title eq "" or $sg eq "" or $rating eq "" or $length eq "" or $description eq "") {
			print qq|<h3 align="center">You forgot to fill in one of the form elements.</h3><br>\n|;
		} else {
			$sql = "insert into catalog (media,title,sg,rating,length,description,system) values (?,?,?,?,?,?,?)";
			$sth = $dbh->prepare($sql);
			$sth->execute($media,$title,$sg,$rating,$length,$description,$system);
			$error = $dbh->errstr;
			$sth->finish;

			if ($error ne "") {
				handle($error,$script);
				die "Database Error: ${error}";
			}

			print qq|<h3 align="center">Entry Successful!</h3><br>\n|;
		}
	}
}

#########################################################################################################
#
# Print the new media entry form.
#
#

print <<HTML;
<h1 align="center">New Media Entry</h1>

<center>
	<form method="POST" action="newmedia.cgi">
		<input type="hidden" name="media" value="1">

		<table width="75%" border="1" bgcolor="#000000">
			<tr>
				<td width="100%" align="center" colspan="2" bgcolor="#D3C1B6">
					<strong>
						New Book Entry
					</strong>
				</td>
			</tr>

			<tr>
				<td width="20%" bgcolor="#D3C1B6">Title: </td>
				<td width="80%" bgcolor="#D3C1B6"><input type="text" name="title" size="30"></td>
			</tr>

			<tr>
				<td width="20%" bgcolor="#D3C1B6">Author: </td>
				<td width="80%" bgcolor="#D3C1B6"><input type="text" name="author" size="30"></td>
			</tr>

			<tr>
				<td width="20%" bgcolor="#D3C1B6">Subject: </td>
				<td width="80%" bgcolor="#D3C1B6"><input type="text" name="sg" size="30"></td>
			</tr>

			<tr>
				<td width="20%" bgcolor="#D3C1B6">Publisher: </td>
				<td width="80%" bgcolor="#D3C1B6"><input type="text" name="publisher" size="30"></td>
			</tr>

			<tr>
				<td width="20%" bgcolor="#D3C1B6">Year of Publication: </td>
				<td width="80%" bgcolor="#D3C1B6"><input type="text" name="year" size="4"></td>
			</tr>

			<tr>
				<td width="20%" bgcolor="#D3C1B6">Short Description: </td>
				<td width="80%" bgcolor="#D3C1B6"><textarea name="description" cols="40" rows="7"></textarea></td>
			</tr>

			<tr>
				<td width="100%" align="left" colspan="2" bgcolor="#D3C1B6"><input type="submit" value="Add Book"></td>
			</tr>
		</table>
	</form>

	<br>

	<form method="POST" action="newmedia.cgi">
		<input type="hidden" name="media" value="2">

		<table width="75%" border="1" bgcolor="#000000">
			<tr>
				<td width="100%" align="center" colspan="2" bgcolor="#D3C1B6"><strong>New Movie Entry</strong></td>
			</tr>

			<tr>
				<td width="20%" bgcolor="#D3C1B6">Title: </td>
				<td width="80%" bgcolor="#D3C1B6"><input type="text" name="title" size="30"></td>
			</tr>

			<tr>
				<td width="20%" bgcolor="#D3C1B6">Genre: </td>
				<td width="80%" bgcolor="#D3C1B6"><input type="text" name="sg" size="30"></td>
			</tr>

			<tr>
				<td width="20%" bgcolor="#D3C1B6">Rating: </td>
				<td width="80%" bgcolor="#D3C1B6">
					<select name="rating" height="1">
						<option value="G">G</option>
						<option value="PG">PG</option>
						<option selected value="PG-13">PG-13</option>
						<option value="R">R</option>
						<option value="NR">NR</option>
						<option value="X">X</option>
						<option value="XXX">XXX</option>
					</select>
				</td>
			</tr>

			<tr>
				<td width="20%" bgcolor="#D3C1B6">Length (minutes): </td>
				<td width="80%" bgcolor="#D3C1B6"><input type="text" name="length" size="3"></td>
			</tr>

			<tr>
				<td width="20%" bgcolor="#D3C1B6">Short Description: </td>
				<td width="80%" bgcolor="#D3C1B6"><textarea name="description" cols="40" rows="7"></textarea></td>
			</tr>

			<tr>
				<td width="20%" bgcolor="#D3C1B6">System: </td>
				<td width="80%" bgcolor="#D3C1B6">
					<select name="system" height="1">
						<option value="1">VHS Videocasette</option>
						<option value="2">DVD Disc</option>
					</select>
				</td>
			</tr>

			<tr>
				<td width="100%" align="left" colspan="2" bgcolor="#D3C1B6"><input type="submit" value="Add Movie"></td>
			</tr>
		</table>
	</form>
</center>
HTML

print <<HTML;
<center>
	<a href="index.html"><strong>Return to the Staff Page</strong></a>
	<br><img border="0" src="/images/book.gif" width="116" height="68">
	
	<p><h5>
		Web design by Jennifer Joy Hawkins
		<br>Copyright (C) 2000 Jennifer Joy Hawkins
		<br>All Rights Reserved
	</h5></p>
</center>
</body>

</html>
HTML

$dbh->disconnect;
