#!/usr/bin/perl

###########################################################################
#            Copyright (C) 2000 John David Ratliff                        #
#                                                                         #
# Permission is hereby granted, free of charge, to any person obtaining   #
# a copy of this software and associated documentation files (the         #
# "Software"), to deal in the Software without restriction, including     #
# without limitation the rights to use, copy, modify, merge, publish,     #
# distribute, sublicense, and/or sell copies of the Software, and to      #
# permit persons to whom the Software is furnished to do so, subject to   #
# the following conditions:                                               #
#                                                                         #
# The above copyright notice and this permission notice shall be included #
# in all copies or substantial portions of the Software.                  #
#                                                                         #
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,         #
# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF      #
# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  #
# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY    #
# CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,    #
# TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE       #
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.                  #
###########################################################################

use CGI qw(:param);
use DBI;

require "../lib/dbi-connect.pl";
require "../lib/date.pl";
require "../lib/error.pl";

##################################################################################
#
# Declare the local variables, print the content type, set the script variable,
# establish the database connection, and print the header
#

local ($script,$dbh,$error,$email,$sql,$sth,$id,$name,$street,$city,$zip);
local ($phone,$month,$day,$year,$gender,@ctime,$dob,$now,$age,$nodisplay);

print "Content-type: text/html\n\n";

$script = "staff/patron.cgi";
$dbh = dbiConnect($dbname);

print <<HTML;
<html>

<head>
	<title>Examine Patron Information</title>

	<style fprolloverstyle>
		A:hover {color: darkgreen; font-weight: bold}
	</style>
</head>

<body background="/images/background.gif" link="#800000" vlink="#C00000" alink="#000080">
HTML

##################################################################################
#
# Find Patron ID number based on the patron's email address
#
#

if (param("findid")) {
	$email = param("email");

	$sql = "select id,name,street from patrons where email = ?";
	$sth = $dbh->prepare($sql);
	$sth->execute($email);
	$error = $dbh->errstr;
	($id,$name,$street) = $sth->fetchrow_array();
	$sth->finish;

	if ($error ne "") {
		handle($error,$script);
		die "Database Error: ${error}";
	}

	print qq|<h3 align="center">Patron's ID: ${id}<br>Name: ${name}<br>Street: ${street}</h3>\n|;

##################################################################################
#
# Print the patron's information table obtained from their ID number
#
#

} elsif (param()) {
	$id = param("id");

	$sql = "select name,email,street,city,zip,phone,gender,month,day,year from patrons where id = ?";
	$sth = $dbh->prepare($sql);
	$sth->execute($id);
	$error = $dbh->errstr;
	($name,$email,$street,$city,$zip,$phone,$gender,$month,$day,$year) = $sth->fetchrow_array();
	$sth->finish;

	if ($error ne "") {
		handle($error,$script);
		die "Database Error: ${error}";
	}

	(@ctime) = localtime(time);
	$ctime[5]+=1900;
	$ctime[4]++;

	if ($ctime[4] < 10) {
		$now = "0$ctime[4]";
	} else {
		$now = "$ctime[4]";
	}

	if ($ctime[3] < 10) {
		$now .= "0$ctime[3]";
	} else {
		$now .= "$ctime[3]";
	}

	if ($month < 10) {
		$dob = "0${month}";
	} else {
		$dob = "${month}";
	}

	if ($day < 10) {
		$dob .= "0${day}";
	} else {
		$dob .= "${day}";
	}

	$age = $ctime[5] - $year;

	if ($dob > $now) {
		$age--;
	}

	$month = getMonthName($month);

	print qq|<h1 align="center">Patron Information</h1>\n|;

	print qq|<center><table width="75%" border="1" bgcolor="#000000">\n|;
	print qq|<tr><td width="20%" bgcolor="#D3C1B6" align="center">Name: </td><td width="80%" bgcolor="#D3C1B6">${name}</td></tr>\n|;
	print qq|<tr><td width="20%" bgcolor="#D3C1B6" align="center">Email: </td><td width="80%" bgcolor="#D3C1B6">${email}</td></tr>\n|;
	print qq|<tr><td width="20%" bgcolor="#D3C1B6" align="center">Street: </td><td width="80%" bgcolor="#D3C1B6">${street}</td></tr>\n|;
	print qq|<tr><td width="20%" bgcolor="#D3C1B6" align="center">City: </td><td width="80%" bgcolor="#D3C1B6">${city}</td></tr>\n|;
	print qq|<tr><td width="20%" bgcolor="#D3C1B6" align="center">Zipcode: </td><td width="80%" bgcolor="#D3C1B6">${zip}</td></tr>\n|;
	print qq|<tr><td width="20%" bgcolor="#D3C1B6" align="center">Telephone: </td><td width="80%" bgcolor="#D3C1B6">${phone}</td></tr>\n|;
	print qq|<tr><td width="20%" bgcolor="#D3C1B6" align="center">Gender: </td><td width="80%" bgcolor="#D3C1B6">${gender}</td></tr>\n|;
	print qq|<tr><td width="20%" bgcolor="#D3C1B6" align="center">DOB: </td><td width="80%" bgcolor="#D3C1B6">${month} ${day}, ${year} [${age} Years Old]</td></tr>\n|;
	print qq|</table></center><br>\n|;

	$nodisplay = 1;
}

##################################################################################
#
# Unless we're told not to, print the ID obtaining form.
#
#

if ($nodisplay == 0) {
	print <<HTML;
<h1 align="center">Examine Patron Information</h1>

<center>
	<form method="POST" action="patron.cgi">
		<table width="75%" border="1" bgcolor="#000000">
			<tr>
				<td width="100%" align="center" bgcolor="#D3C1B6" colspan="2"><strong>Examine Patron Information</strong></td>
			</tr>

			<tr>
				<td width="20%" align="center" bgcolor="#D3C1B6">Patron ID: </td>
				<td width="80%" bgcolor="#D3C1B6"><input type="text" name="id" size="5"> <font size="-1"><a href="#patron">Find Patron ID Number</a></font></td>
			</tr>

			<tr>
				<td width="100%" colspan="2" align="left" bgcolor="#D3C1B6"><input type="submit" value="Examine Patron Information"></td>
			</tr>
		</table>
	</form>

	<hr width="50%" color="#A00000">

	<a name="patron">
		<form method="POST" action="patron.cgi">
			<input type="hidden" name="findid" value="1">

			<table width="75%" border="1" bgcolor="#000000">
				<tr>
					<td width="100%" colspan="2" align="center" bgcolor="#D3C1B6"><strong>Find Patron ID</strong></td>
				</tr>

				<tr>
					<td width="20%" align="center" bgcolor="#D3C1B6">Patron E-Mail: </td>
					<td width="80%" bgcolor="#D3C1B6"><input type="text" name="email" size="30"></td>
				</tr>

				<tr>
					<td width="100%" colspan="2" align="left" bgcolor="#D3C1B6"><input type="submit" value="Find Patron ID"></td>
				</tr>
			</table>
		</form>
	</a>
</center>
HTML
}

print <<HTML;
<center>
	<a href="index.html"><strong>Return to the Staff Page</strong></a>
	<br><img border="0" src="/images/book.gif" width="116" height="68">
	
	<p><h5>
		Web design by Jennifer Joy Hawkins
		<br>Copyright (C) 2000 Jennifer Joy Hawkins
		<br>All Rights Reserved
	</h5></p>
</center>
</body>

</html>
HTML

$dbh->disconnect;
