#!/usr/bin/perl

###########################################################################
#            Copyright (C) 2000 John David Ratliff                        #
#                                                                         #
# Permission is hereby granted, free of charge, to any person obtaining   #
# a copy of this software and associated documentation files (the         #
# "Software"), to deal in the Software without restriction, including     #
# without limitation the rights to use, copy, modify, merge, publish,     #
# distribute, sublicense, and/or sell copies of the Software, and to      #
# permit persons to whom the Software is furnished to do so, subject to   #
# the following conditions:                                               #
#                                                                         #
# The above copyright notice and this permission notice shall be included #
# in all copies or substantial portions of the Software.                  #
#                                                                         #
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,         #
# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF      #
# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  #
# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY    #
# CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,    #
# TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE       #
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.                  #
###########################################################################

use CGI qw(:param);
use DBI;

require "../lib/dbi-connect.pl";
require "../lib/error.pl";

#########################################################################################################
#
# Declare the local variables, print the content type, setup the script variable, establish the database
# connection, and print the header
#

local ($script,$dbh,$error,$email,$sql,$sth,$id,$name,$street,$paid,$fines);

print "Content-type: text/html\n\n";

$script = "staff/payment.cgi";
$dbh = dbiConnect($dbname);

print <<HTML;
<html>

<head>
	<title>Fine Payment/Assessment System</title>

	<style fprolloverstyle>
		A:hover {color: darkgreen; font-weight: bold}
	</style>
</head>

<body background="/images/background.gif" link="#800000" vlink="#C00000" alink="#000080">
HTML

#########################################################################################################
#
# Lookup patron ID numbers based on the email address
#
#

if (param("findid")) {
	$email = param("email");

	$sql = "select id,name,street from patrons where email = ?";
	$sth = $dbh->prepare($sql);
	$sth->execute($email);
	$error = $dbh->errstr;
	($id,$name,$street) = $sth->fetchrow_array();
	$sth->finish;

	if ($error ne "") {
		handle($error,$script);
		die "Database Error: ${error}";
	}

	print qq|<h3 align="center">Patron's ID: ${id}<br>Name: ${name}<br>Street: ${street}</h3>\n|;

#########################################################################################################
#
# Collect or Assess fines based on value of paid. Negative values equal assessments while positive values
# are payments. Refunds are not allowed.
#

} elsif (param("payment")) {
	$id = param("id");
	$paid = param("paid");
	$fines = param("fines");
	$name = param("name");
	$email = param("email");

	$fines-=$paid;

	if ($fines < 0) {
		$fines = "0.00";
	}

	$sql = "update patrons set fines = $fines where id = $id";
	$dbh->do($sql);
	$error = $dbh->errstr;

	if ($error ne "") {
		handle($error,$script);
		die "Database Error: ${error}";
	}

	open(MAIL,"|/usr/sbin/sendmail ${email}");
	print MAIL "To: ${name} <${email}>\n";
	print MAIL "From: Library Staff <${email}>\n";

	if ($paid > 0) {
		print qq|<h3 align="center">${name} has paid \$${paid} towards his late fines. The patron now owes \$${fines}.</h3>\n|;

		print MAIL "Subject: Fine Payment Receipt\n\n";
		print MAIL "This is a record to keep regarding the payment of your fines today.\n";
		print MAIL "You paid \$${paid} towards your fines. You currently owe \$${fines} in fines to the library.\n";

		
	} else {
		print qq|<h3 align="center">${name} has been fined \$${paid}. The patron now owes \$${fines}.</h3>\n|;

		print MAIL "Subject: Fine Assessment Record\n\n";
		print MAIL "You have been fined \$${paid} by the library staff. You currently owe \$${fines} in fines to the library.\n";
	}


	print MAIL "\nIf you have any questions, please feel free to contact the library staff by replying to this email.\n";
	print MAIL "Or visit our web site and send us feedback at ${server}\n";
	print MAIL "\nLibrary Staff\n${staffmail}\n\n";
	close(MAIL);

#########################################################################################################
#
# Based on the patron's ID number, print a payment form listing the amount of fines owed.
#
#

} elsif (param()) {
	$id = param("patron");

	$sql = "select name,email,fines from patrons where id = ?";
	$sth = $dbh->prepare($sql);
	$sth->execute($id);
	$error = $dbh->errstr;
	($name,$email,$fines) = $sth->fetchrow_array();
	$sth->finish;

	if ($error ne "") {
		handle($error,$script);
		die "Database Error: ${error}";
	}

	print qq|<h1 align="center">Fine Payment/Assessment System</h1>\n|;
	print qq|<center><table width="75%" bgcolor="#000000" border="1"><form method="POST" action="payment.cgi">\n|;
	print qq|<input type="hidden" name="id" value="${id}"><input type="hidden" name="name" value="${name}"><input type="hidden" name="email" value="${email}"><input type="hidden" name="fines" value="${fines}"><input type="hidden" name="payment" value="1">\n|;
	print qq|<tr><td width="100%" bgcolor="#D3C1B6" align="center" colspan="2"><strong>${name} has accrued \$${fines} in fines.</strong></td></tr>\n|;
	print qq|<tr><td width="20%" bgcolor="#D3C1B6" align="center">Amount Paid: </td><td width="80%" bgcolor="#D3C1B6"><input type="text" name="paid"> <font size="-1">Please enter in amount in dollars and cents (dollars decimal cents).</td></tr>\n|;
	print qq|<tr><td width="100%" bgcolor="#D3C1B6" align="left" colspan="2"><input type="submit" value="Pay Fines"></td></tr>\n|;
	print qq|</form></table></center>\n|;
} else {

#########################################################################################################
#
# Print the Patron ID obtaining form
#
#

	print <<HTML;
<h1 align="center">Fine Payment/Assessment System</h1>

<center>
	<form method="POST" action="payment.cgi">
		<table width="75%" bgcolor="#000000" border="1">
			<tr>
				<td width="100%" bgcolor="#D3C1B6" align="center" colspan="2"><strong>Collect Patron Late Fees</strong></td>
			</tr>

			<tr>
				<td width="20%" bgcolor="#D3C1B6" align="center">Patron ID: </td>
				<td width="80%" bgcolor="#D3C1B6"><input type="text" name="patron"> <font size="-1"><a href="#patron">Search for Patron ID</a></font></td>
			</tr>

			<tr>
				<td width="100%" bgcolor="#D3C1B6" align="left" colspan="2"><input type="submit" value="Access Account"></td>
			</tr>
		</table>
	</form>

	<hr width="50%" color="#A00000">

	<form method="POST" action="payment.cgi">
		<input type="hidden" name="findid" value="1">

		<table width="75%" bgcolor="#000000" border="1">
			<tr>
				<td width="100%" bgcolor="#D3C1B6" align="center" colspan="2"><strong>Find Patron ID</strong></td>
			</tr>

			<tr>
				<td width="20%" bgcolor="#D3C1B6" align="center">Patron E-Mail: </td>
				<td width="80%" bgcolor="#D3C1B6"><input type="text" name="email"> <font size="-1"><a href="#patron">Search for Patron ID</a></font></td>
			</tr>

			<tr>
				<td width="100%" bgcolor="#D3C1B6" align="left" colspan="2"><input type="submit" value="Find Patron ID"></td>
			</tr>
		</table>
	</form>
</center>
HTML
}

print <<HTML;
<center>
	<a href="index.html"><strong>Return to the Staff Page</strong></a>
	<br><img border="0" src="/images/book.gif" width="116" height="68">
	
	<p><h5>
		Web design by Jennifer Joy Hawkins
		<br>Copyright (C) 2000 Jennifer Joy Hawkins
		<br>All Rights Reserved
	</h5></p>
</center>
</body>

</html>
HTML

$dbh->disconnect;
