#!/usr/bin/perl

###########################################################################
#            Copyright (C) 2000 John David Ratliff                        #
#                                                                         #
# Permission is hereby granted, free of charge, to any person obtaining   #
# a copy of this software and associated documentation files (the         #
# "Software"), to deal in the Software without restriction, including     #
# without limitation the rights to use, copy, modify, merge, publish,     #
# distribute, sublicense, and/or sell copies of the Software, and to      #
# permit persons to whom the Software is furnished to do so, subject to   #
# the following conditions:                                               #
#                                                                         #
# The above copyright notice and this permission notice shall be included #
# in all copies or substantial portions of the Software.                  #
#                                                                         #
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,         #
# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF      #
# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  #
# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY    #
# CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,    #
# TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE       #
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.                  #
###########################################################################

use CGI qw(:param);
use DBI;

require "../lib/dbi-connect.pl";
require "../lib/error.pl";

#########################################################################################################
#
# Declare the local variables, print the content type, define the script name, establish the database
# connection, and print the header
#

local ($script,$dbh,$error,$email,$sql,$sth,$id,$name,$street);
local ($media,$reserve,$title,$author,$description,$name,$email);

print "Content-type: text/html\n\n";

$script = "staff/reserve.cgi";
$dbh = dbiConnect($dbname);

print <<HTML;
<html>

<head>
	<title>Reserve Item for Patron</title>

	<style fprolloverstyle>
		A:hover {color: darkgreen; font-weight: bold}
	</style>
</head>

<body background="/images/background.gif" link="#800000" vlink="#C00000" alink="#000080">
HTML

#########################################################################################################
#
# find the ID number of a patron based on their email address
#
#

if (param("findid")) {
	$email = param("email");

	$sql = "select id,name,street from patrons where email = ?";
	$sth = $dbh->prepare($sql);
	$sth->execute($email);
	$error = $dbh->errstr;
	($id,$name,$street) = $sth->fetchrow_array();
	$sth->finish;

	if ($error ne "") {
		handle($error,$script);
		die "Database Error: ${error}";
	}

	print qq|<h3 align="center">Patron's ID: ${id}<br>Name: ${name}<br>Street: ${street}</h3>\n|;

#########################################################################################################
#
# Reserve an item for a patron unless the item has already got a hold on it.
#
#

} elsif (param()) {
	$id = param("id");
	$patron = param("patron");

	$sql = "select media,reserve,title,author,description from catalog where id = ?";
	$sth = $dbh->prepare($sql);
	$sth->execute($id);
	$error = $dbh->errstr;
	($media,$reserve,$title,$author,$description) = $sth->fetchrow_array();
	$sth->finish;

	if ($error ne "") {
		handle($error,$script);
		die "Database Error: ${error}";
	}

	if ($reserve == 0 or $reserve == $patron) {
		$sql = "select name,email from patrons where id = ?";
		$sth = $dbh->prepare($sql);
		$sth->execute($patron);
		$error = $dbh->errstr;
		($name,$email) = $sth->fetchrow_array();
		$sth->finish;

		if ($error ne "") {
			handle($error,$script);
			die "Database Error: ${error}";
		}

		$sql = "update catalog set reserve = $patron, rtime = NULL where id = $id";
		$dbh->do($sql);
		$error = $dbh->errstr;

		if ($error ne "") {
			handle($error,$script);
			die "Database Error: ${error}";
		}

		print qq|<h3 align="center">This item has been reserved for ${name} who has been notified to pick it up via email.</h3>\n|;

		open(MAIL,"|/usr/sbin/sendmail ${email}");
		print MAIL "To: ${name} <${email}>\n";
		print MAIL "From: Library Staff <${staffmail}>\n";
		print MAIL "Subject: Your Item Has Been Reserved\n\n";
		print MAIL "Item ID: ${id}\n";
		print MAIL "Title: ${title}\n";

		if ($author ne "") {
			print MAIL "Author: ${author}\n";
		}

		print MAIL "Description: ${description}\n";

		print MAIL "\nYou have 7 days to pick it up before it will be returned to the shelves.\n";
		print MAIL "To cancel your reservation, go to the URL ${server}/reserve.cgi?id=${id}\n";
		print MAIL "\nLibrary Staff\n${staffmail}\n\n";
		close(MAIL);
	} else {
		$sql = "select name,email from patrons where id = ?";
		$sth = $dbh->prepare($sql);
		$sth->execute($reserve);
		$error = $dbh->errstr;
		($name,$email) = $sth->fetchrow_array();
		$sth->finish;

		if ($error ne "") {
			handle($error,$script);
			die "Database Error: ${error}";
		}

		print qq|<h3 align="center">This item has already been reserved for ${name}.</h3>\n|;
		print qq|<h4 align="center"><a href="reserve.cgi?id=${id}&patron=${reserve}&media=${media}">Click here to reserve the item for this patron.</a></h4>\n|;
	}
}

#########################################################################################################
#
# Print the reservation form.
#
#

print <<HTML;
<h1 align="center">Library Reservation System</h1>

<center>
	<form method="POST" action="reserve.cgi">
		<table width="75%" border="1" bgcolor="#000000">
			<tr>
				<td width="100%" bgcolor="#D3C1B6" align="center" colspan="2"><strong>Reserve an Item for a Patron</strong></td>
			</tr>

			<tr>
				<td width="20%" bgcolor="#D3C1B6">Catalog ID: </td>
				<td width="80%" bgcolor="#D3C1B6"><input type="text" name="id" size="5"> <font size="-1"><a href="../search.html" target="_blank">Find the ID Number</a></font></td>
			</tr>

			<tr>
				<td width="20%" bgcolor="#D3C1B6">Patron ID: </td>
				<td width="80%" bgcolor="#D3C1B6"><input type="text" name="patron" size="5"> <font size="-1"><a href="#patron">Find the Patron's ID Number</a></font></td>
			</tr>

			<tr>
				<td width="100%" colspan="2" align="left" bgcolor="#D3C1B6"><input type="submit" value="Reserve Item"></td>
			</tr>
		</table>
	</form>

	<hr width="50%" color="#A00000">

	<a name="patron">
		<form method="POST" action="reserve.cgi">
			<input type="hidden" name="findid" value="1">

			<table width="75%" border="1" bgcolor="#000000">
				<tr>
					<td width="100%" colspan="2" align="center" bgcolor="#D3C1B6"><strong>Find Patron ID</strong></td>
				</tr>

				<tr>
					<td width="20%" align="center" bgcolor="#D3C1B6">Patron E-Mail: </td>
					<td width="80%" bgcolor="#D3C1B6"><input type="text" name="email" size="30"></td>
				</tr>

				<tr>
					<td width="100%" colspan="2" align="left" bgcolor="#D3C1B6"><input type="submit" value="Find Patron ID"></td>
				</tr>
			</table>
		</form>
	</a>
</center>
HTML

print <<HTML;
<center>
	<a href="index.html"><strong>Return to the Staff Page</strong></a>
	<br><img border="0" src="/images/book.gif" width="116" height="68">
	
	<p><h5>
		Web design by Jennifer Joy Hawkins
		<br>Copyright (C) 2000 Jennifer Joy Hawkins
		<br>All Rights Reserved
	</h5></p>
</center>
</body>

</html>
HTML

$dbh->disconnect;
