#!/usr/bin/perl

###########################################################################
#            Copyright (C) 2000 John David Ratliff                        #
#                                                                         #
# Permission is hereby granted, free of charge, to any person obtaining   #
# a copy of this software and associated documentation files (the         #
# "Software"), to deal in the Software without restriction, including     #
# without limitation the rights to use, copy, modify, merge, publish,     #
# distribute, sublicense, and/or sell copies of the Software, and to      #
# permit persons to whom the Software is furnished to do so, subject to   #
# the following conditions:                                               #
#                                                                         #
# The above copyright notice and this permission notice shall be included #
# in all copies or substantial portions of the Software.                  #
#                                                                         #
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,         #
# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF      #
# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  #
# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY    #
# CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,    #
# TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE       #
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.                  #
###########################################################################

use CGI qw(:param);
use DBI;

require "../lib/dbi-connect.pl";
require "../lib/error.pl";

###############################################################################
#
# declare the local variables, set the content type, set the script name,
# establish the database connection, and print the header
#

local ($script,$dbh,$error,$id,$sql,$media,$title,$author,$sg,$publisher);
local ($description,$sth,$rating,$length,$system,$type,$nodisplay,$year,$lost);

print "Content-type: text/html\n\n";

$script = "staff/update.cgi";
$dbh = dbiConnect($dbname);

print <<HTML;
<html>

<head>
	<title>Update the Library Catalog</title>

	<style fprolloverstyle>
		A:hover {color: darkgreen; font-weight: bold}
	</style>
</head>

<body background="/images/background.gif" link="#800000" vlink="#C00000" alink="#000080">
HTML

###############################################################################
#
# updates the catalog with the new item information given by the update form
#

if (param("update")) {
	$media = param("media");
	$id = param("id");
	$title = param("title");
	$sg = param("sg");
	$description = param("description");
	$lost = param("lost");

	if ($media == 1) {
		$author = param("author");
		$publisher = param("publisher");
		$year = param("year");

		$sql = "update catalog set title = ?, author = ?, sg = ?, publisher = ?, year = ?, description = ?, lost = ? where id = ?";
		$sth = $dbh->prepare($sql);
		$sth->execute($title,$author,$sg,$publisher,$year,$description,$lost,$id);
		$error = $dbh->errstr;
		$sth->finish;
	} elsif ($media == 2) {
		$rating = param("rating");
		$length = param("length");
		$system = param("system");

		$sql = "update catalog set title = ?, sg = ?, rating = ?, length = ?, system = ?, description = ?, lost = ? where id = ?";
		$sth = $dbh->prepare($sql);
		$sth->execute($title,$sg,$rating,$length,$system,$description,$lost,$id);
		$error = $dbh->errstr;
		$sth->finish;
	}

	if ($error ne "") {
		handle($error,$script);
		die "Database Error: ${error}";
	}

	print qq|<h3 align="center">The catalog has been successfully updated.</h3>\n|;

###############################################################################
#
# draws the item information update form by getting the info from the database
#

} elsif (param()) {
	$id = param("id");

	$sql = "select media from catalog where id = ?";
	$sth = $dbh->prepare($sql);
	$sth->execute($id);
	$error = $dbh->errstr;
	$media = $sth->fetchrow_array();
	$sth->finish;

	if ($error ne "") {
		handle($error,$script);
		die "Database Error: ${error}";
	}

	print qq|<h1 align="center">Update the Library Catalog</h1>\n|;

	if ($media == 1) {
		$sql = "select title,author,sg,publisher,year,description,lost from catalog where id = ?";
		$sth = $dbh->prepare($sql);
		$sth->execute($id);
		$error = $dbh->errstr;
		($title,$author,$sg,$publisher,$year,$description,$lost) = $sth->fetchrow_array();
		$sth->finish;

		if ($error ne "") {
			handle($error,$script);
			die "Database Error: ${error}";
		}

		print qq|<center><table width="75%" bgcolor="#000000" border="1"><form method="POST" action="update.cgi">\n|;
		print qq|<input type="hidden" name="update" value="1"><input type="hidden" name="id" value="${id}"><input type="hidden" name="media" value="${media}">\n|;
		print qq|<tr><td width="20%" align="center" bgcolor="#D3C1B6">Book ID: </td><td width="80%" bgcolor="#D3C1B6">${id}</td></tr>\n|;
		print qq|<tr><td width="20%" align="center" bgcolor="#D3C1B6">Title: </td><td width="80%" bgcolor="#D3C1B6"><input type="text" name="title" value="${title}" size="50"></td></tr>\n|;
		print qq|<tr><td width="20%" align="center" bgcolor="#D3C1B6">Author: </td><td width="80%" bgcolor="#D3C1B6"><input type="text" name="author" value="${author}" size="50"></td></tr>\n|;
		print qq|<tr><td width="20%" align="center" bgcolor="#D3C1B6">Subject: </td><td width="80%" bgcolor="#D3C1B6"><input type="text" name="sg" value="${sg}" size="50"></td></tr>\n|;
		print qq|<tr><td width="20%" align="center" bgcolor="#D3C1B6">Publisher: </td><td width="80%" bgcolor="#D3C1B6"><input type="text" name="publisher" value="${publisher}" size="30"></td></tr>\n|;
		print qq|<tr><td width="20%" align="center" bgcolor="#D3C1B6">Year of Publication: </td><td width="80%" bgcolor="#D3C1B6"><input type="text" name="year" value="${year}" size="4"></td></tr>\n|;
		print qq|<tr><td width="20%" align="center" bgcolor="#D3C1B6">Description: </td><td width="80%" bgcolor="#D3C1B6"><textarea name="description" rows="7" cols="40">${description}</textarea></td></tr>\n|;
		print qq|<tr><td width="20%" align="center" bgcolor="#D3C1B6">Remove from Catalog? </td><td width="80%" bgcolor="#D3C1B6">|;

		if ($lost == 1) {
			print qq|<input type="checkbox" name="lost" value="1" checked></td></tr>\n|;
		} else {
			print qq|<input type="checkbox" name="lost" value="1"></td></tr>\n|;
		}

		print qq|<tr><td width="100%" bgcolor="#D3C1B6" colspan="2" align="left"><input type="submit" value="Update Catalog"></td></tr>\n|;
		print qq|</form></table></center>\n|;
	} elsif ($media == 2) {
		$sql = "select title,sg,rating,length,description,system,lost from catalog where id = ?";
		$sth = $dbh->prepare($sql);
		$sth->execute($id);
		$error = $dbh->errstr;
		($title,$sg,$rating,$length,$description,$system,$lost) = $sth->fetchrow_array();
		$sth->finish;

		if ($error ne "") {
			handle($error,$script);
			die "Database Error: ${error}";
		}

		print qq|<center><table width="75%" bgcolor="#000000" border="1"><form method="POST" action="update.cgi">\n|;
		print qq|<input type="hidden" name="update" value="1"><input type="hidden" name="id" value="${id}"><input type="hidden" name="media" value="${media}">\n|;
		print qq|<tr><td width="20%" align="center" bgcolor="#D3C1B6">Movie ID: </td><td width="80%" bgcolor="#D3C1B6">${id}</td></tr>\n|;
		print qq|<tr><td width="20%" align="center" bgcolor="#D3C1B6">Title: </td><td width="80%" bgcolor="#D3C1B6"><input type="text" name="title" value="${title}" size="50"></td></tr>\n|;
		print qq|<tr><td width="20%" align="center" bgcolor="#D3C1B6">Genre: </td><td width="80%" bgcolor="#D3C1B6"><input type="text" name="sg" value="${sg}" size="50"></td></tr>\n|;
		print qq|<tr><td width="20%" align="center" bgcolor="#D3C1B6">Rating: </td><td width="80%" bgcolor="#D3C1B6"><select name="rating" height="1">|;

		foreach $type ("G","PG","PG-13","R","X","XXX") {
			if ($rating eq $type) {
				print qq|<option selected value="${type}">${type}</option>|;
			} else {
				print qq|<option value="${type}">${type}</option>|;
			}
		}

		print qq|</td></tr>\n|;
		print qq|<tr><td width="20%" align="center" bgcolor="#D3C1B6">Length: </td><td width="80%" bgcolor="#D3C1B6"><input type="text" name="length" value="${length}" size="30"></td></tr>\n|;
		print qq|<tr><td width="20%" align="center" bgcolor="#D3C1B6">System: </td><td width="80%" bgcolor="#D3C1B6">\n<select name="system" height="1">\n|;

		if ($system == 1) {
			print qq|<option selected value="1">VHS Videocasette</option>\n<option value="2">DVD Disc</option>\n</select>\n|;
		} elsif ($system == 2) {
			print qq|<option value="1">VHS Videocasette</option>\n<option selected value="2">DVD Disc</option>\n</select>\n|;
		}

		print qq|<tr><td width="20%" align="center" bgcolor="#D3C1B6">Description: </td><td width="80%" bgcolor="#D3C1B6"><textarea name="description" rows="7" cols="40">${description}</textarea></td></tr>\n|;
		print qq|<tr><td width="20%" align="center" bgcolor="#D3C1B6">Remove from Catalog? </td><td width="80%" bgcolor="#D3C1B6">|;

		if ($lost == 1) {
			print qq|<input type="checkbox" name="lost" value="1" checked></td></tr>\n|;
		} else {
			print qq|<input type="checkbox" name="lost" value="1"></td></tr>\n|;
		}

		print qq|<tr><td width="100%" bgcolor="#D3C1B6" colspan="2" align="left"><input type="submit" value="Update Catalog"></td></tr>\n|;
		print qq|</form></table></center>\n|;
	}

	$nodisplay = 1;
	print "<br>\n";
}

###############################################################################
#
# Unless we've been told not to, draw the Catalog ID inquiry form
#

if ($nodisplay != 1) {
	print <<HTML;
<h1 align="center">Update an Item in the Library Catalog</h1>

<center>
	<form method="POST" action="update.cgi">
		<table width="75%" border="1" bgcolor="#000000">
			<tr>
				<td width="100%" bgcolor="#D3C1B6" align="center" colspan="2"><strong>Update a Book</strong></td>
			</tr>

			</tr>

			<tr>
				<td width="20%" bgcolor="#D3C1B6">Catalog ID: </td>
				<td width="80%" bgcolor="#D3C1B6"><input type="text" name="id" size="5"> <font size="-1"><a href="../search.html" target="_blank">Need to find the ID Number?</a></font></td>
			</tr>

			<tr>
				<td width="100%" colspan="2" align="left" bgcolor="#D3C1B6"><input type="submit" value="Begin Updating"></td>
			</tr>
		</table>
	</form>
</center>
HTML
}

print <<HTML;
<center>
	<a href="index.html"><strong>Return to the Staff Page</strong></a>
	<br><img border="0" src="/images/book.gif" width="116" height="68">
	
	<p><h5>
		Web design by Jennifer Joy Hawkins
		<br>Copyright (C) 2000 Jennifer Joy Hawkins
		<br>All Rights Reserved
	</h5></p>
</center>
</body>

</html>
HTML

$dbh->disconnect;
