#!/usr/bin/perl

###########################################################################
#            Copyright (C) 2000 John David Ratliff                        #
#                                                                         #
# Permission is hereby granted, free of charge, to any person obtaining   #
# a copy of this software and associated documentation files (the         #
# "Software"), to deal in the Software without restriction, including     #
# without limitation the rights to use, copy, modify, merge, publish,     #
# distribute, sublicense, and/or sell copies of the Software, and to      #
# permit persons to whom the Software is furnished to do so, subject to   #
# the following conditions:                                               #
#                                                                         #
# The above copyright notice and this permission notice shall be included #
# in all copies or substantial portions of the Software.                  #
#                                                                         #
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,         #
# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF      #
# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  #
# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY    #
# CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,    #
# TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE       #
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.                  #
###########################################################################

use CGI qw(:param);
use DBI;

require "lib/dbi-connect.pl";
require "lib/error.pl";

#########################################################################################################
#
# Declare the local variables, print the content type, set the script variable, establish the database
# connection and print the header
#

local ($script,$dbh,$error,$media,$title,$author,$sg,$description,$id,$sql,$sth);

print "Content-type: text/html\n\n";

$script = "suggest.cgi";
$dbh = dbiConnect($dbname);

print <<HTML;
<html>

<head>
	<title>Suggest an Item to the Library</title>

	<style fprolloverstyle>
		A:hover {color: darkgreen; font-weight: bold}
	</style>
</head>

<body background="/images/background.gif" link="#800000" vlink="#C00000" alink="#000080">
HTML

$media = param("media");
$title = param("title");
$author = param("author");
$sg = param("sg");
$description = param("description");

#########################################################################################################
#
# Check to make sure the input is valid
#
#

if ($title eq "" or $description eq "") {
	print qq|<h3 align="center">You must fill in the title and description fields.</h3>\n|;
} elsif (length($title) > 100 or length($author) > 100 or length($sg) > 50) {
	print qq|<h3 align="center">One of your fields is too long. Titles and authors are limited to 100 characters. Subjects and Genres are limited to 50 characters.</h3>\n|;

#########################################################################################################
#
# Enter the suggestion into the suggestions database
#
#

} else {
	$sql = "select id from catalog where title = ? and media = ?";
	$sth = $dbh->prepare($sql);
	$sth->execute($title,$media);
	$error = $dbh->errstr;
	$id = $sth->fetchrow_array();
	$sth->finish;

	if ($error ne "") {
		handle($error,$script);
		die "Database Error: ${error}";
	}

	if ($id != 0) {
		print qq|<h3 align="center">We already have that item.</h3>\n|;

		print qq|\n<center><a href="search.cgi?media=${media}&search=${title}&searchby=title"><strong>click here to check the staus of this item.</strong></a></center>\n|;
	} else {
		$sql = "insert into suggestions (media,title,author,sg,description) values (?,?,?,?,?)";
		$sth = $dbh->prepare($sql);
		$sth->execute($media,$title,$author,$sg,$description);
		$error = $dbh->errstr;
		$sth->finish;

		if ($error ne "") {
			handle($error,$script);
			die "Database Error: ${error}";
		}

		print qq|<center>\n<table width="75%" border="1" bgcolor="#000000">\n|;
		print qq|<tr><td width="100%" align="center" colspan="2" bgcolor="#D3C1B6"><strong>Thank You for Suggesting This Item</strong></td></tr>\n|;
		print qq|<tr><td width="20%" bgcolor="#D3C1B6">Title: </td><td width="80%" bgcolor="#D3C1B6">${title}</td></tr>\n|;

		if ($media == 1) {
			print qq|<tr><td width="20%" bgcolor="#D3C1B6">Author: </td><td width="80%" bgcolor="#D3C1B6">${author}</td></tr>\n|;
			print qq|<tr><td width="20%" bgcolor="#D3C1B6">Subject: </td><td width="80%" bgcolor="#D3C1B6">${sg}</td></tr>\n|;
		} elsif ($media == 2) {
			print qq|<tr><td width="20%" bgcolor="#D3C1B6">Genre: </td><td width="80%" bgcolor="#D3C1B6">${sg}</td></tr>\n|;
		}

		print qq|<tr><td width="20%" bgcolor="#D3C1B6">Description: </td><td width="80%" bgcolor="#D3C1B6">${description}</td></tr>\n|;
		print qq|</table>\n</center>\n<br>\n|;
	}
}

print qq|<br><center><a href="index.html"><strong>Return to the Main Page</strong></a><br><img border="0" src="/images/book.gif" width="116" height="68"></center>\n</body>\n</html>\n|;

$dbh->disconnect;
